Class: Aws::MachineLearning::Types::BatchPrediction
- Inherits:
-
Struct
- Object
- Struct
- Aws::MachineLearning::Types::BatchPrediction
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-machinelearning/types.rb
Overview
Represents the output of a GetBatchPrediction operation.
The content consists of the detailed metadata, the status, and the data file information of a ‘Batch Prediction`.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#batch_prediction_data_source_id ⇒ String
The ID of the
DataSourcethat points to the group of observations to predict. -
#batch_prediction_id ⇒ String
The ID assigned to the
BatchPredictionat creation. -
#compute_time ⇒ Integer
Long integer type that is a 64-bit signed number.
-
#created_at ⇒ Time
The time that the
BatchPredictionwas created. -
#created_by_iam_user ⇒ String
The AWS user account that invoked the
BatchPrediction. -
#finished_at ⇒ Time
A timestamp represented in epoch time.
-
#input_data_location_s3 ⇒ String
The location of the data file or directory in Amazon Simple Storage Service (Amazon S3).
-
#invalid_record_count ⇒ Integer
Long integer type that is a 64-bit signed number.
-
#last_updated_at ⇒ Time
The time of the most recent edit to the
BatchPrediction. -
#message ⇒ String
A description of the most recent details about processing the batch prediction request.
-
#ml_model_id ⇒ String
The ID of the
MLModelthat generated predictions for theBatchPredictionrequest. -
#name ⇒ String
A user-supplied name or description of the
BatchPrediction. -
#output_uri ⇒ String
The location of an Amazon S3 bucket or directory to receive the operation results.
-
#started_at ⇒ Time
A timestamp represented in epoch time.
-
#status ⇒ String
The status of the
BatchPrediction. -
#total_record_count ⇒ Integer
Long integer type that is a 64-bit signed number.
Instance Attribute Details
#batch_prediction_data_source_id ⇒ String
The ID of the DataSource that points to the group of observations to predict.
148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 148 class BatchPrediction < Struct.new( :batch_prediction_id, :ml_model_id, :batch_prediction_data_source_id, :input_data_location_s3, :created_by_iam_user, :created_at, :last_updated_at, :name, :status, :output_uri, :message, :compute_time, :finished_at, :started_at, :total_record_count, :invalid_record_count) SENSITIVE = [] include Aws::Structure end |
#batch_prediction_id ⇒ String
The ID assigned to the BatchPrediction at creation. This value should be identical to the value of the BatchPredictionID in the request.
148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 148 class BatchPrediction < Struct.new( :batch_prediction_id, :ml_model_id, :batch_prediction_data_source_id, :input_data_location_s3, :created_by_iam_user, :created_at, :last_updated_at, :name, :status, :output_uri, :message, :compute_time, :finished_at, :started_at, :total_record_count, :invalid_record_count) SENSITIVE = [] include Aws::Structure end |
#compute_time ⇒ Integer
Long integer type that is a 64-bit signed number.
148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 148 class BatchPrediction < Struct.new( :batch_prediction_id, :ml_model_id, :batch_prediction_data_source_id, :input_data_location_s3, :created_by_iam_user, :created_at, :last_updated_at, :name, :status, :output_uri, :message, :compute_time, :finished_at, :started_at, :total_record_count, :invalid_record_count) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The time that the BatchPrediction was created. The time is expressed in epoch time.
148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 148 class BatchPrediction < Struct.new( :batch_prediction_id, :ml_model_id, :batch_prediction_data_source_id, :input_data_location_s3, :created_by_iam_user, :created_at, :last_updated_at, :name, :status, :output_uri, :message, :compute_time, :finished_at, :started_at, :total_record_count, :invalid_record_count) SENSITIVE = [] include Aws::Structure end |
#created_by_iam_user ⇒ String
The AWS user account that invoked the BatchPrediction. The account type can be either an AWS root account or an AWS Identity and Access Management (IAM) user account.
148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 148 class BatchPrediction < Struct.new( :batch_prediction_id, :ml_model_id, :batch_prediction_data_source_id, :input_data_location_s3, :created_by_iam_user, :created_at, :last_updated_at, :name, :status, :output_uri, :message, :compute_time, :finished_at, :started_at, :total_record_count, :invalid_record_count) SENSITIVE = [] include Aws::Structure end |
#finished_at ⇒ Time
A timestamp represented in epoch time.
148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 148 class BatchPrediction < Struct.new( :batch_prediction_id, :ml_model_id, :batch_prediction_data_source_id, :input_data_location_s3, :created_by_iam_user, :created_at, :last_updated_at, :name, :status, :output_uri, :message, :compute_time, :finished_at, :started_at, :total_record_count, :invalid_record_count) SENSITIVE = [] include Aws::Structure end |
#input_data_location_s3 ⇒ String
The location of the data file or directory in Amazon Simple Storage Service (Amazon S3).
148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 148 class BatchPrediction < Struct.new( :batch_prediction_id, :ml_model_id, :batch_prediction_data_source_id, :input_data_location_s3, :created_by_iam_user, :created_at, :last_updated_at, :name, :status, :output_uri, :message, :compute_time, :finished_at, :started_at, :total_record_count, :invalid_record_count) SENSITIVE = [] include Aws::Structure end |
#invalid_record_count ⇒ Integer
Long integer type that is a 64-bit signed number.
148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 148 class BatchPrediction < Struct.new( :batch_prediction_id, :ml_model_id, :batch_prediction_data_source_id, :input_data_location_s3, :created_by_iam_user, :created_at, :last_updated_at, :name, :status, :output_uri, :message, :compute_time, :finished_at, :started_at, :total_record_count, :invalid_record_count) SENSITIVE = [] include Aws::Structure end |
#last_updated_at ⇒ Time
The time of the most recent edit to the BatchPrediction. The time is expressed in epoch time.
148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 148 class BatchPrediction < Struct.new( :batch_prediction_id, :ml_model_id, :batch_prediction_data_source_id, :input_data_location_s3, :created_by_iam_user, :created_at, :last_updated_at, :name, :status, :output_uri, :message, :compute_time, :finished_at, :started_at, :total_record_count, :invalid_record_count) SENSITIVE = [] include Aws::Structure end |
#message ⇒ String
A description of the most recent details about processing the batch prediction request.
148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 148 class BatchPrediction < Struct.new( :batch_prediction_id, :ml_model_id, :batch_prediction_data_source_id, :input_data_location_s3, :created_by_iam_user, :created_at, :last_updated_at, :name, :status, :output_uri, :message, :compute_time, :finished_at, :started_at, :total_record_count, :invalid_record_count) SENSITIVE = [] include Aws::Structure end |
#ml_model_id ⇒ String
The ID of the MLModel that generated predictions for the BatchPrediction request.
148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 148 class BatchPrediction < Struct.new( :batch_prediction_id, :ml_model_id, :batch_prediction_data_source_id, :input_data_location_s3, :created_by_iam_user, :created_at, :last_updated_at, :name, :status, :output_uri, :message, :compute_time, :finished_at, :started_at, :total_record_count, :invalid_record_count) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
A user-supplied name or description of the BatchPrediction.
148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 148 class BatchPrediction < Struct.new( :batch_prediction_id, :ml_model_id, :batch_prediction_data_source_id, :input_data_location_s3, :created_by_iam_user, :created_at, :last_updated_at, :name, :status, :output_uri, :message, :compute_time, :finished_at, :started_at, :total_record_count, :invalid_record_count) SENSITIVE = [] include Aws::Structure end |
#output_uri ⇒ String
The location of an Amazon S3 bucket or directory to receive the operation results. The following substrings are not allowed in the ‘s3 key` portion of the outputURI field: ’:‘, ’//‘, ’/./‘, ’/../‘.
148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 148 class BatchPrediction < Struct.new( :batch_prediction_id, :ml_model_id, :batch_prediction_data_source_id, :input_data_location_s3, :created_by_iam_user, :created_at, :last_updated_at, :name, :status, :output_uri, :message, :compute_time, :finished_at, :started_at, :total_record_count, :invalid_record_count) SENSITIVE = [] include Aws::Structure end |
#started_at ⇒ Time
A timestamp represented in epoch time.
148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 148 class BatchPrediction < Struct.new( :batch_prediction_id, :ml_model_id, :batch_prediction_data_source_id, :input_data_location_s3, :created_by_iam_user, :created_at, :last_updated_at, :name, :status, :output_uri, :message, :compute_time, :finished_at, :started_at, :total_record_count, :invalid_record_count) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the BatchPrediction. This element can have one of the following values:
-
PENDING- Amazon Machine Learning (Amazon ML) submitted a request to generate predictions for a batch of observations. -
INPROGRESS- The process is underway. -
FAILED- The request to perform a batch prediction did not run to completion. It is not usable. -
COMPLETED- The batch prediction process completed successfully. -
DELETED- TheBatchPredictionis marked as deleted. It is not usable.
148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 148 class BatchPrediction < Struct.new( :batch_prediction_id, :ml_model_id, :batch_prediction_data_source_id, :input_data_location_s3, :created_by_iam_user, :created_at, :last_updated_at, :name, :status, :output_uri, :message, :compute_time, :finished_at, :started_at, :total_record_count, :invalid_record_count) SENSITIVE = [] include Aws::Structure end |
#total_record_count ⇒ Integer
Long integer type that is a 64-bit signed number.
148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 148 class BatchPrediction < Struct.new( :batch_prediction_id, :ml_model_id, :batch_prediction_data_source_id, :input_data_location_s3, :created_by_iam_user, :created_at, :last_updated_at, :name, :status, :output_uri, :message, :compute_time, :finished_at, :started_at, :total_record_count, :invalid_record_count) SENSITIVE = [] include Aws::Structure end |