Class: Aws::MachineLearning::Types::CreateBatchPredictionInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::MachineLearning::Types::CreateBatchPredictionInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-machinelearning/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#batch_prediction_data_source_id ⇒ String
The ID of the
DataSourcethat points to the group of observations to predict. -
#batch_prediction_id ⇒ String
A user-supplied ID that uniquely identifies the
BatchPrediction. -
#batch_prediction_name ⇒ String
A user-supplied name or description of the
BatchPrediction. -
#ml_model_id ⇒ String
The ID of the
MLModelthat will generate predictions for the group of observations. -
#output_uri ⇒ String
The location of an Amazon Simple Storage Service (Amazon S3) bucket or directory to store the batch prediction results.
Instance Attribute Details
#batch_prediction_data_source_id ⇒ String
The ID of the DataSource that points to the group of observations to predict.
203 204 205 206 207 208 209 210 211 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 203 class CreateBatchPredictionInput < Struct.new( :batch_prediction_id, :batch_prediction_name, :ml_model_id, :batch_prediction_data_source_id, :output_uri) SENSITIVE = [] include Aws::Structure end |
#batch_prediction_id ⇒ String
A user-supplied ID that uniquely identifies the BatchPrediction.
203 204 205 206 207 208 209 210 211 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 203 class CreateBatchPredictionInput < Struct.new( :batch_prediction_id, :batch_prediction_name, :ml_model_id, :batch_prediction_data_source_id, :output_uri) SENSITIVE = [] include Aws::Structure end |
#batch_prediction_name ⇒ String
A user-supplied name or description of the BatchPrediction. BatchPredictionName can only use the UTF-8 character set.
203 204 205 206 207 208 209 210 211 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 203 class CreateBatchPredictionInput < Struct.new( :batch_prediction_id, :batch_prediction_name, :ml_model_id, :batch_prediction_data_source_id, :output_uri) SENSITIVE = [] include Aws::Structure end |
#ml_model_id ⇒ String
The ID of the MLModel that will generate predictions for the group of observations.
203 204 205 206 207 208 209 210 211 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 203 class CreateBatchPredictionInput < Struct.new( :batch_prediction_id, :batch_prediction_name, :ml_model_id, :batch_prediction_data_source_id, :output_uri) SENSITIVE = [] include Aws::Structure end |
#output_uri ⇒ String
The location of an Amazon Simple Storage Service (Amazon S3) bucket or directory to store the batch prediction results. The following substrings are not allowed in the ‘s3 key` portion of the outputURI field: ’:‘, ’//‘, ’/./‘, ’/../‘.
Amazon ML needs permissions to store and retrieve the logs on your behalf. For information about how to set permissions, see the [Amazon Machine Learning Developer Guide].
203 204 205 206 207 208 209 210 211 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 203 class CreateBatchPredictionInput < Struct.new( :batch_prediction_id, :batch_prediction_name, :ml_model_id, :batch_prediction_data_source_id, :output_uri) SENSITIVE = [] include Aws::Structure end |