Class: Aws::MachineLearning::Types::CreateBatchPredictionOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-machinelearning/types.rb

Overview

Represents the output of a CreateBatchPrediction operation, and is an acknowledgement that Amazon ML received the request.

The CreateBatchPrediction operation is asynchronous. You can poll for status updates by using the ‘>GetBatchPrediction` operation and checking the Status parameter of the result.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#batch_prediction_idString

A user-supplied ID that uniquely identifies the BatchPrediction. This value is identical to the value of the BatchPredictionId in the request.



226
227
228
229
230
# File 'lib/aws-sdk-machinelearning/types.rb', line 226

class CreateBatchPredictionOutput < Struct.new(
  :batch_prediction_id)
  SENSITIVE = []
  include Aws::Structure
end