Class: Aws::MachineLearning::Types::CreateDataSourceFromRDSOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::MachineLearning::Types::CreateDataSourceFromRDSOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-machinelearning/types.rb
Overview
Represents the output of a CreateDataSourceFromRDS operation, and is an acknowledgement that Amazon ML received the request.
The CreateDataSourceFromRDS> operation is asynchronous. You can poll for updates by using the GetBatchPrediction operation and checking the Status parameter. You can inspect the Message when Status shows up as FAILED. You can also check the progress of the copy operation by going to the DataPipeline console and looking up the pipeline using the ‘pipelineId ` from the describe call.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#data_source_id ⇒ String
A user-supplied ID that uniquely identifies the datasource.
Instance Attribute Details
#data_source_id ⇒ String
A user-supplied ID that uniquely identifies the datasource. This value should be identical to the value of the DataSourceID in the request.
335 336 337 338 339 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 335 class CreateDataSourceFromRDSOutput < Struct.new( :data_source_id) SENSITIVE = [] include Aws::Structure end |