Class: Aws::MachineLearning::Types::CreateDataSourceFromRedshiftOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::MachineLearning::Types::CreateDataSourceFromRedshiftOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-machinelearning/types.rb
Overview
Represents the output of a CreateDataSourceFromRedshift operation, and is an acknowledgement that Amazon ML received the request.
The CreateDataSourceFromRedshift operation is asynchronous. You can poll for updates by using the GetBatchPrediction operation and checking the Status parameter.
Instance Attribute Summary collapse
-
#data_source_id ⇒ String
A user-supplied ID that uniquely identifies the datasource.
Instance Attribute Details
#data_source_id ⇒ String
A user-supplied ID that uniquely identifies the datasource. This value should be identical to the value of the DataSourceID in the request.
486 487 488 489 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 486 class CreateDataSourceFromRedshiftOutput < Struct.new( :data_source_id) include Aws::Structure end |