Class: Aws::MachineLearning::Types::CreateDataSourceFromS3Input
- Inherits:
-
Struct
- Object
- Struct
- Aws::MachineLearning::Types::CreateDataSourceFromS3Input
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-machinelearning/types.rb
Overview
When making an API call, you may pass CreateDataSourceFromS3Input data as a hash:
{
data_source_id: "EntityId", # required
data_source_name: "EntityName",
data_spec: { # required
data_location_s3: "S3Url", # required
data_rearrangement: "DataRearrangement",
data_schema: "DataSchema",
data_schema_location_s3: "S3Url",
},
compute_statistics: false,
}
Instance Attribute Summary collapse
-
#compute_statistics ⇒ Boolean
The compute statistics for a
DataSource. -
#data_source_id ⇒ String
A user-supplied identifier that uniquely identifies the
DataSource. -
#data_source_name ⇒ String
A user-supplied name or description of the
DataSource. -
#data_spec ⇒ Types::S3DataSpec
The data specification of a
DataSource:.
Instance Attribute Details
#compute_statistics ⇒ Boolean
The compute statistics for a DataSource. The statistics are generated from the observation data referenced by a DataSource. Amazon ML uses the statistics internally during MLModel training. This parameter must be set to true if the DataSource needs to be used for MLModel training.
540 541 542 543 544 545 546 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 540 class CreateDataSourceFromS3Input < Struct.new( :data_source_id, :data_source_name, :data_spec, :compute_statistics) include Aws::Structure end |
#data_source_id ⇒ String
A user-supplied identifier that uniquely identifies the DataSource.
540 541 542 543 544 545 546 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 540 class CreateDataSourceFromS3Input < Struct.new( :data_source_id, :data_source_name, :data_spec, :compute_statistics) include Aws::Structure end |
#data_source_name ⇒ String
A user-supplied name or description of the DataSource.
540 541 542 543 544 545 546 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 540 class CreateDataSourceFromS3Input < Struct.new( :data_source_id, :data_source_name, :data_spec, :compute_statistics) include Aws::Structure end |
#data_spec ⇒ Types::S3DataSpec
The data specification of a DataSource:
-
DataLocationS3 - The Amazon S3 location of the observation data.
-
DataSchemaLocationS3 - The Amazon S3 location of the
DataSchema. -
DataSchema - A JSON string representing the schema. This is not required if
DataSchemaUriis specified. -
DataRearrangement - A JSON string that represents the splitting and rearrangement requirements for the
Datasource.Sample - ‘ “”splitting“:{”percentBegin“:10,”percentEnd“:60}”`
540 541 542 543 544 545 546 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 540 class CreateDataSourceFromS3Input < Struct.new( :data_source_id, :data_source_name, :data_spec, :compute_statistics) include Aws::Structure end |