Class: Aws::MachineLearning::Types::CreateDataSourceFromS3Output
- Inherits:
-
Struct
- Object
- Struct
- Aws::MachineLearning::Types::CreateDataSourceFromS3Output
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-machinelearning/types.rb
Overview
Represents the output of a CreateDataSourceFromS3 operation, and is an acknowledgement that Amazon ML received the request.
The CreateDataSourceFromS3 operation is asynchronous. You can poll for updates by using the GetBatchPrediction operation and checking the Status parameter.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#data_source_id ⇒ String
A user-supplied ID that uniquely identifies the
DataSource.
Instance Attribute Details
#data_source_id ⇒ String
A user-supplied ID that uniquely identifies the DataSource. This value should be identical to the value of the DataSourceID in the request.
488 489 490 491 492 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 488 class CreateDataSourceFromS3Output < Struct.new( :data_source_id) SENSITIVE = [] include Aws::Structure end |