Class: Aws::MachineLearning::Types::CreateEvaluationOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::MachineLearning::Types::CreateEvaluationOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-machinelearning/types.rb
Overview
Represents the output of a CreateEvaluation operation, and is an acknowledgement that Amazon ML received the request.
CreateEvaluation operation is asynchronous. You can poll for status updates by using the GetEvcaluation operation and checking the Status parameter.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#evaluation_id ⇒ String
The user-supplied ID that uniquely identifies the
Evaluation.
Instance Attribute Details
#evaluation_id ⇒ String
The user-supplied ID that uniquely identifies the Evaluation. This value should be identical to the value of the EvaluationId in the request.
536 537 538 539 540 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 536 class CreateEvaluationOutput < Struct.new( :evaluation_id) SENSITIVE = [] include Aws::Structure end |