Class: Aws::MachineLearning::Types::CreateMLModelInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::MachineLearning::Types::CreateMLModelInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-machinelearning/types.rb
Overview
When making an API call, you may pass CreateMLModelInput data as a hash:
{
ml_model_id: "EntityId", # required
ml_model_name: "EntityName",
ml_model_type: "REGRESSION", # required, accepts REGRESSION, BINARY, MULTICLASS
parameters: {
"StringType" => "StringType",
},
training_data_source_id: "EntityId", # required
recipe: "Recipe",
recipe_uri: "S3Url",
}
Instance Attribute Summary collapse
-
#ml_model_id ⇒ String
A user-supplied ID that uniquely identifies the
MLModel. -
#ml_model_name ⇒ String
A user-supplied name or description of the
MLModel. -
#ml_model_type ⇒ String
The category of supervised learning that this
MLModelwill address. -
#parameters ⇒ Hash<String,String>
A list of the training parameters in the
MLModel. -
#recipe ⇒ String
The data recipe for creating the
MLModel. -
#recipe_uri ⇒ String
The Amazon Simple Storage Service (Amazon S3) location and file name that contains the
MLModelrecipe. -
#training_data_source_id ⇒ String
The
DataSourcethat points to the training data.
Instance Attribute Details
#ml_model_id ⇒ String
A user-supplied ID that uniquely identifies the MLModel.
726 727 728 729 730 731 732 733 734 735 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 726 class CreateMLModelInput < Struct.new( :ml_model_id, :ml_model_name, :ml_model_type, :parameters, :training_data_source_id, :recipe, :recipe_uri) include Aws::Structure end |
#ml_model_name ⇒ String
A user-supplied name or description of the MLModel.
726 727 728 729 730 731 732 733 734 735 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 726 class CreateMLModelInput < Struct.new( :ml_model_id, :ml_model_name, :ml_model_type, :parameters, :training_data_source_id, :recipe, :recipe_uri) include Aws::Structure end |
#ml_model_type ⇒ String
The category of supervised learning that this MLModel will address. Choose from the following types:
-
Choose
REGRESSIONif theMLModelwill be used to predict a numeric value. -
Choose
BINARYif theMLModelresult has two possible values. -
Choose
MULTICLASSif theMLModelresult has a limited number of values.
For more information, see the [Amazon Machine Learning Developer Guide][1].
726 727 728 729 730 731 732 733 734 735 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 726 class CreateMLModelInput < Struct.new( :ml_model_id, :ml_model_name, :ml_model_type, :parameters, :training_data_source_id, :recipe, :recipe_uri) include Aws::Structure end |
#parameters ⇒ Hash<String,String>
A list of the training parameters in the MLModel. The list is implemented as a map of key-value pairs.
The following is the current set of training parameters:
-
sgd.maxMLModelSizeInBytes- The maximum allowed size of the model. Depending on the input data, the size of the model might affect its performance.The value is an integer that ranges from
100000to2147483648. The default value is33554432. -
sgd.maxPasses- The number of times that the training process traverses the observations to build theMLModel. The value is an integer that ranges from1to10000. The default value is10. -
sgd.shuffleType- Whether Amazon ML shuffles the training data. Shuffling the data improves a model’s ability to find the optimal solution for a variety of data types. The valid values areautoandnone. The default value isnone. We <?oxy_insert_start author=“laurama” timestamp=“20160329T131121-0700”>strongly recommend that you shuffle your data.<?oxy_insert_end> -
sgd.l1RegularizationAmount- The coefficient regularization L1 norm. It controls overfitting the data by penalizing large coefficients. This tends to drive coefficients to zero, resulting in a sparse feature set. If you use this parameter, start by specifying a small value, such as1.0E-08.The value is a double that ranges from
0toMAX_DOUBLE. The default is to not use L1 normalization. This parameter can’t be used whenL2is specified. Use this parameter sparingly. -
sgd.l2RegularizationAmount- The coefficient regularization L2 norm. It controls overfitting the data by penalizing large coefficients. This tends to drive coefficients to small, nonzero values. If you use this parameter, start by specifying a small value, such as1.0E-08.The value is a double that ranges from
0toMAX_DOUBLE. The default is to not use L2 normalization. This parameter can’t be used whenL1is specified. Use this parameter sparingly.
726 727 728 729 730 731 732 733 734 735 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 726 class CreateMLModelInput < Struct.new( :ml_model_id, :ml_model_name, :ml_model_type, :parameters, :training_data_source_id, :recipe, :recipe_uri) include Aws::Structure end |
#recipe ⇒ String
The data recipe for creating the MLModel. You must specify either the recipe or its URI. If you don’t specify a recipe or its URI, Amazon ML creates a default.
726 727 728 729 730 731 732 733 734 735 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 726 class CreateMLModelInput < Struct.new( :ml_model_id, :ml_model_name, :ml_model_type, :parameters, :training_data_source_id, :recipe, :recipe_uri) include Aws::Structure end |
#recipe_uri ⇒ String
The Amazon Simple Storage Service (Amazon S3) location and file name that contains the MLModel recipe. You must specify either the recipe or its URI. If you don’t specify a recipe or its URI, Amazon ML creates a default.
726 727 728 729 730 731 732 733 734 735 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 726 class CreateMLModelInput < Struct.new( :ml_model_id, :ml_model_name, :ml_model_type, :parameters, :training_data_source_id, :recipe, :recipe_uri) include Aws::Structure end |
#training_data_source_id ⇒ String
The DataSource that points to the training data.
726 727 728 729 730 731 732 733 734 735 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 726 class CreateMLModelInput < Struct.new( :ml_model_id, :ml_model_name, :ml_model_type, :parameters, :training_data_source_id, :recipe, :recipe_uri) include Aws::Structure end |