Class: Aws::MachineLearning::Types::CreateMLModelOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::MachineLearning::Types::CreateMLModelOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-machinelearning/types.rb
Overview
Represents the output of a CreateMLModel operation, and is an acknowledgement that Amazon ML received the request.
The CreateMLModel operation is asynchronous. You can poll for status updates by using the GetMLModel operation and checking the Status parameter.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#ml_model_id ⇒ String
A user-supplied ID that uniquely identifies the
MLModel.
Instance Attribute Details
#ml_model_id ⇒ String
A user-supplied ID that uniquely identifies the MLModel. This value should be identical to the value of the MLModelId in the request.
657 658 659 660 661 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 657 class CreateMLModelOutput < Struct.new( :ml_model_id) SENSITIVE = [] include Aws::Structure end |