Class: Aws::MachineLearning::Types::DataSource
- Inherits:
-
Struct
- Object
- Struct
- Aws::MachineLearning::Types::DataSource
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-machinelearning/types.rb
Overview
Represents the output of the GetDataSource operation.
The content consists of the detailed metadata and data file information and the current status of the DataSource.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#compute_statistics ⇒ Boolean
The parameter is
trueif statistics need to be generated from the observation data. -
#compute_time ⇒ Integer
Long integer type that is a 64-bit signed number.
-
#created_at ⇒ Time
The time that the
DataSourcewas created. -
#created_by_iam_user ⇒ String
The AWS user account from which the
DataSourcewas created. -
#data_location_s3 ⇒ String
The location and name of the data in Amazon Simple Storage Service (Amazon S3) that is used by a
DataSource. -
#data_rearrangement ⇒ String
A JSON string that represents the splitting and rearrangement requirement used when this
DataSourcewas created. -
#data_size_in_bytes ⇒ Integer
The total number of observations contained in the data files that the
DataSourcereferences. -
#data_source_id ⇒ String
The ID that is assigned to the
DataSourceduring creation. -
#finished_at ⇒ Time
A timestamp represented in epoch time.
-
#last_updated_at ⇒ Time
The time of the most recent edit to the
BatchPrediction. -
#message ⇒ String
A description of the most recent details about creating the
DataSource. -
#name ⇒ String
A user-supplied name or description of the
DataSource. -
#number_of_files ⇒ Integer
The number of data files referenced by the
DataSource. -
#rds_metadata ⇒ Types::RDSMetadata
The datasource details that are specific to Amazon RDS.
-
#redshift_metadata ⇒ Types::RedshiftMetadata
Describes the
DataSourcedetails specific to Amazon Redshift. -
#role_arn ⇒ String
The Amazon Resource Name (ARN) of an [AWS IAM Role], such as the following: arn:aws:iam::account:role/rolename.
-
#started_at ⇒ Time
A timestamp represented in epoch time.
-
#status ⇒ String
The current status of the
DataSource.
Instance Attribute Details
#compute_statistics ⇒ Boolean
The parameter is true if statistics need to be generated from the observation data.
803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 803 class DataSource < Struct.new( :data_source_id, :data_location_s3, :data_rearrangement, :created_by_iam_user, :created_at, :last_updated_at, :data_size_in_bytes, :number_of_files, :name, :status, :message, :redshift_metadata, :rds_metadata, :role_arn, :compute_statistics, :compute_time, :finished_at, :started_at) SENSITIVE = [] include Aws::Structure end |
#compute_time ⇒ Integer
Long integer type that is a 64-bit signed number.
803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 803 class DataSource < Struct.new( :data_source_id, :data_location_s3, :data_rearrangement, :created_by_iam_user, :created_at, :last_updated_at, :data_size_in_bytes, :number_of_files, :name, :status, :message, :redshift_metadata, :rds_metadata, :role_arn, :compute_statistics, :compute_time, :finished_at, :started_at) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The time that the DataSource was created. The time is expressed in epoch time.
803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 803 class DataSource < Struct.new( :data_source_id, :data_location_s3, :data_rearrangement, :created_by_iam_user, :created_at, :last_updated_at, :data_size_in_bytes, :number_of_files, :name, :status, :message, :redshift_metadata, :rds_metadata, :role_arn, :compute_statistics, :compute_time, :finished_at, :started_at) SENSITIVE = [] include Aws::Structure end |
#created_by_iam_user ⇒ String
The AWS user account from which the DataSource was created. The account type can be either an AWS root account or an AWS Identity and Access Management (IAM) user account.
803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 803 class DataSource < Struct.new( :data_source_id, :data_location_s3, :data_rearrangement, :created_by_iam_user, :created_at, :last_updated_at, :data_size_in_bytes, :number_of_files, :name, :status, :message, :redshift_metadata, :rds_metadata, :role_arn, :compute_statistics, :compute_time, :finished_at, :started_at) SENSITIVE = [] include Aws::Structure end |
#data_location_s3 ⇒ String
The location and name of the data in Amazon Simple Storage Service (Amazon S3) that is used by a DataSource.
803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 803 class DataSource < Struct.new( :data_source_id, :data_location_s3, :data_rearrangement, :created_by_iam_user, :created_at, :last_updated_at, :data_size_in_bytes, :number_of_files, :name, :status, :message, :redshift_metadata, :rds_metadata, :role_arn, :compute_statistics, :compute_time, :finished_at, :started_at) SENSITIVE = [] include Aws::Structure end |
#data_rearrangement ⇒ String
A JSON string that represents the splitting and rearrangement requirement used when this DataSource was created.
803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 803 class DataSource < Struct.new( :data_source_id, :data_location_s3, :data_rearrangement, :created_by_iam_user, :created_at, :last_updated_at, :data_size_in_bytes, :number_of_files, :name, :status, :message, :redshift_metadata, :rds_metadata, :role_arn, :compute_statistics, :compute_time, :finished_at, :started_at) SENSITIVE = [] include Aws::Structure end |
#data_size_in_bytes ⇒ Integer
The total number of observations contained in the data files that the DataSource references.
803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 803 class DataSource < Struct.new( :data_source_id, :data_location_s3, :data_rearrangement, :created_by_iam_user, :created_at, :last_updated_at, :data_size_in_bytes, :number_of_files, :name, :status, :message, :redshift_metadata, :rds_metadata, :role_arn, :compute_statistics, :compute_time, :finished_at, :started_at) SENSITIVE = [] include Aws::Structure end |
#data_source_id ⇒ String
The ID that is assigned to the DataSource during creation.
803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 803 class DataSource < Struct.new( :data_source_id, :data_location_s3, :data_rearrangement, :created_by_iam_user, :created_at, :last_updated_at, :data_size_in_bytes, :number_of_files, :name, :status, :message, :redshift_metadata, :rds_metadata, :role_arn, :compute_statistics, :compute_time, :finished_at, :started_at) SENSITIVE = [] include Aws::Structure end |
#finished_at ⇒ Time
A timestamp represented in epoch time.
803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 803 class DataSource < Struct.new( :data_source_id, :data_location_s3, :data_rearrangement, :created_by_iam_user, :created_at, :last_updated_at, :data_size_in_bytes, :number_of_files, :name, :status, :message, :redshift_metadata, :rds_metadata, :role_arn, :compute_statistics, :compute_time, :finished_at, :started_at) SENSITIVE = [] include Aws::Structure end |
#last_updated_at ⇒ Time
The time of the most recent edit to the BatchPrediction. The time is expressed in epoch time.
803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 803 class DataSource < Struct.new( :data_source_id, :data_location_s3, :data_rearrangement, :created_by_iam_user, :created_at, :last_updated_at, :data_size_in_bytes, :number_of_files, :name, :status, :message, :redshift_metadata, :rds_metadata, :role_arn, :compute_statistics, :compute_time, :finished_at, :started_at) SENSITIVE = [] include Aws::Structure end |
#message ⇒ String
A description of the most recent details about creating the DataSource.
803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 803 class DataSource < Struct.new( :data_source_id, :data_location_s3, :data_rearrangement, :created_by_iam_user, :created_at, :last_updated_at, :data_size_in_bytes, :number_of_files, :name, :status, :message, :redshift_metadata, :rds_metadata, :role_arn, :compute_statistics, :compute_time, :finished_at, :started_at) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
A user-supplied name or description of the DataSource.
803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 803 class DataSource < Struct.new( :data_source_id, :data_location_s3, :data_rearrangement, :created_by_iam_user, :created_at, :last_updated_at, :data_size_in_bytes, :number_of_files, :name, :status, :message, :redshift_metadata, :rds_metadata, :role_arn, :compute_statistics, :compute_time, :finished_at, :started_at) SENSITIVE = [] include Aws::Structure end |
#number_of_files ⇒ Integer
The number of data files referenced by the DataSource.
803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 803 class DataSource < Struct.new( :data_source_id, :data_location_s3, :data_rearrangement, :created_by_iam_user, :created_at, :last_updated_at, :data_size_in_bytes, :number_of_files, :name, :status, :message, :redshift_metadata, :rds_metadata, :role_arn, :compute_statistics, :compute_time, :finished_at, :started_at) SENSITIVE = [] include Aws::Structure end |
#rds_metadata ⇒ Types::RDSMetadata
The datasource details that are specific to Amazon RDS.
803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 803 class DataSource < Struct.new( :data_source_id, :data_location_s3, :data_rearrangement, :created_by_iam_user, :created_at, :last_updated_at, :data_size_in_bytes, :number_of_files, :name, :status, :message, :redshift_metadata, :rds_metadata, :role_arn, :compute_statistics, :compute_time, :finished_at, :started_at) SENSITIVE = [] include Aws::Structure end |
#redshift_metadata ⇒ Types::RedshiftMetadata
Describes the DataSource details specific to Amazon Redshift.
803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 803 class DataSource < Struct.new( :data_source_id, :data_location_s3, :data_rearrangement, :created_by_iam_user, :created_at, :last_updated_at, :data_size_in_bytes, :number_of_files, :name, :status, :message, :redshift_metadata, :rds_metadata, :role_arn, :compute_statistics, :compute_time, :finished_at, :started_at) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The Amazon Resource Name (ARN) of an [AWS IAM Role], such as the following: arn:aws:iam::account:role/rolename.
[1]: docs.aws.amazon.com/IAM/latest/UserGuide/roles-toplevel.html#roles-about-termsandconcepts
803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 803 class DataSource < Struct.new( :data_source_id, :data_location_s3, :data_rearrangement, :created_by_iam_user, :created_at, :last_updated_at, :data_size_in_bytes, :number_of_files, :name, :status, :message, :redshift_metadata, :rds_metadata, :role_arn, :compute_statistics, :compute_time, :finished_at, :started_at) SENSITIVE = [] include Aws::Structure end |
#started_at ⇒ Time
A timestamp represented in epoch time.
803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 803 class DataSource < Struct.new( :data_source_id, :data_location_s3, :data_rearrangement, :created_by_iam_user, :created_at, :last_updated_at, :data_size_in_bytes, :number_of_files, :name, :status, :message, :redshift_metadata, :rds_metadata, :role_arn, :compute_statistics, :compute_time, :finished_at, :started_at) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the DataSource. This element can have one of the following values:
-
PENDING - Amazon Machine Learning (Amazon ML) submitted a request to create a
DataSource. -
INPROGRESS - The creation process is underway.
-
FAILED - The request to create a
DataSourcedid not run to completion. It is not usable. -
COMPLETED - The creation process completed successfully.
-
DELETED - The
DataSourceis marked as deleted. It is not usable.
803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 803 class DataSource < Struct.new( :data_source_id, :data_location_s3, :data_rearrangement, :created_by_iam_user, :created_at, :last_updated_at, :data_size_in_bytes, :number_of_files, :name, :status, :message, :redshift_metadata, :rds_metadata, :role_arn, :compute_statistics, :compute_time, :finished_at, :started_at) SENSITIVE = [] include Aws::Structure end |