Class: Aws::MachineLearning::Types::DeleteBatchPredictionOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::MachineLearning::Types::DeleteBatchPredictionOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-machinelearning/types.rb
Overview
Represents the output of a DeleteBatchPrediction operation.
You can use the GetBatchPrediction operation and check the value of the Status parameter to see whether a BatchPrediction is marked as DELETED.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#batch_prediction_id ⇒ String
A user-supplied ID that uniquely identifies the
BatchPrediction.
Instance Attribute Details
#batch_prediction_id ⇒ String
A user-supplied ID that uniquely identifies the BatchPrediction. This value should be identical to the value of the BatchPredictionID in the request.
848 849 850 851 852 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 848 class DeleteBatchPredictionOutput < Struct.new( :batch_prediction_id) SENSITIVE = [] include Aws::Structure end |