Class: Aws::MachineLearning::Types::DeleteEvaluationOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::MachineLearning::Types::DeleteEvaluationOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-machinelearning/types.rb
Overview
Represents the output of a DeleteEvaluation operation. The output indicates that Amazon Machine Learning (Amazon ML) received the request.
You can use the GetEvaluation operation and check the value of the Status parameter to see whether an Evaluation is marked as DELETED.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#evaluation_id ⇒ String
A user-supplied ID that uniquely identifies the
Evaluation.
Instance Attribute Details
#evaluation_id ⇒ String
A user-supplied ID that uniquely identifies the Evaluation. This value should be identical to the value of the EvaluationId in the request.
903 904 905 906 907 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 903 class DeleteEvaluationOutput < Struct.new( :evaluation_id) SENSITIVE = [] include Aws::Structure end |