Class: Aws::MachineLearning::Types::DeleteMLModelOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::MachineLearning::Types::DeleteMLModelOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-machinelearning/types.rb
Overview
Represents the output of a DeleteMLModel operation.
You can use the GetMLModel operation and check the value of the Status parameter to see whether an MLModel is marked as DELETED.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#ml_model_id ⇒ String
A user-supplied ID that uniquely identifies the
MLModel.
Instance Attribute Details
#ml_model_id ⇒ String
A user-supplied ID that uniquely identifies the MLModel. This value should be identical to the value of the MLModelID in the request.
930 931 932 933 934 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 930 class DeleteMLModelOutput < Struct.new( :ml_model_id) SENSITIVE = [] include Aws::Structure end |