Class: Aws::MachineLearning::Types::DescribeBatchPredictionsInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::MachineLearning::Types::DescribeBatchPredictionsInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-machinelearning/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#eq ⇒ String
The equal to operator.
-
#filter_variable ⇒ String
Use one of the following variables to filter a list of
BatchPrediction:. -
#ge ⇒ String
The greater than or equal to operator.
-
#gt ⇒ String
The greater than operator.
-
#le ⇒ String
The less than or equal to operator.
-
#limit ⇒ Integer
The number of pages of information to include in the result.
-
#lt ⇒ String
The less than operator.
-
#ne ⇒ String
The not equal to operator.
-
#next_token ⇒ String
An ID of the page in the paginated results.
-
#prefix ⇒ String
A string that is found at the beginning of a variable, such as
NameorId. -
#sort_order ⇒ String
A two-value parameter that determines the sequence of the resulting list of ‘MLModel`s.
Instance Attribute Details
#eq ⇒ String
The equal to operator. The BatchPrediction results will have FilterVariable values that exactly match the value specified with EQ.
1104 1105 1106 1107 1108 1109 1110 1111 1112 1113 1114 1115 1116 1117 1118 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 1104 class DescribeBatchPredictionsInput < Struct.new( :filter_variable, :eq, :gt, :lt, :ge, :le, :ne, :prefix, :sort_order, :next_token, :limit) SENSITIVE = [] include Aws::Structure end |
#filter_variable ⇒ String
Use one of the following variables to filter a list of BatchPrediction:
-
CreatedAt- Sets the search criteria to theBatchPredictioncreation date. -
Status- Sets the search criteria to theBatchPredictionstatus. -
Name- Sets the search criteria to the contents of theBatchPredictionName. -
IAMUser- Sets the search criteria to the user account that invoked theBatchPredictioncreation. -
MLModelId- Sets the search criteria to theMLModelused in theBatchPrediction. -
DataSourceId- Sets the search criteria to theDataSourceused in theBatchPrediction. -
DataURI- Sets the search criteria to the data file(s) used in theBatchPrediction. The URL can identify either a file or an Amazon Simple Storage Solution (Amazon S3) bucket or directory.
1104 1105 1106 1107 1108 1109 1110 1111 1112 1113 1114 1115 1116 1117 1118 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 1104 class DescribeBatchPredictionsInput < Struct.new( :filter_variable, :eq, :gt, :lt, :ge, :le, :ne, :prefix, :sort_order, :next_token, :limit) SENSITIVE = [] include Aws::Structure end |
#ge ⇒ String
The greater than or equal to operator. The BatchPrediction results will have FilterVariable values that are greater than or equal to the value specified with GE.
1104 1105 1106 1107 1108 1109 1110 1111 1112 1113 1114 1115 1116 1117 1118 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 1104 class DescribeBatchPredictionsInput < Struct.new( :filter_variable, :eq, :gt, :lt, :ge, :le, :ne, :prefix, :sort_order, :next_token, :limit) SENSITIVE = [] include Aws::Structure end |
#gt ⇒ String
The greater than operator. The BatchPrediction results will have FilterVariable values that are greater than the value specified with GT.
1104 1105 1106 1107 1108 1109 1110 1111 1112 1113 1114 1115 1116 1117 1118 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 1104 class DescribeBatchPredictionsInput < Struct.new( :filter_variable, :eq, :gt, :lt, :ge, :le, :ne, :prefix, :sort_order, :next_token, :limit) SENSITIVE = [] include Aws::Structure end |
#le ⇒ String
The less than or equal to operator. The BatchPrediction results will have FilterVariable values that are less than or equal to the value specified with LE.
1104 1105 1106 1107 1108 1109 1110 1111 1112 1113 1114 1115 1116 1117 1118 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 1104 class DescribeBatchPredictionsInput < Struct.new( :filter_variable, :eq, :gt, :lt, :ge, :le, :ne, :prefix, :sort_order, :next_token, :limit) SENSITIVE = [] include Aws::Structure end |
#limit ⇒ Integer
The number of pages of information to include in the result. The range of acceptable values is 1 through 100. The default value is 100.
1104 1105 1106 1107 1108 1109 1110 1111 1112 1113 1114 1115 1116 1117 1118 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 1104 class DescribeBatchPredictionsInput < Struct.new( :filter_variable, :eq, :gt, :lt, :ge, :le, :ne, :prefix, :sort_order, :next_token, :limit) SENSITIVE = [] include Aws::Structure end |
#lt ⇒ String
The less than operator. The BatchPrediction results will have FilterVariable values that are less than the value specified with LT.
1104 1105 1106 1107 1108 1109 1110 1111 1112 1113 1114 1115 1116 1117 1118 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 1104 class DescribeBatchPredictionsInput < Struct.new( :filter_variable, :eq, :gt, :lt, :ge, :le, :ne, :prefix, :sort_order, :next_token, :limit) SENSITIVE = [] include Aws::Structure end |
#ne ⇒ String
The not equal to operator. The BatchPrediction results will have FilterVariable values not equal to the value specified with NE.
1104 1105 1106 1107 1108 1109 1110 1111 1112 1113 1114 1115 1116 1117 1118 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 1104 class DescribeBatchPredictionsInput < Struct.new( :filter_variable, :eq, :gt, :lt, :ge, :le, :ne, :prefix, :sort_order, :next_token, :limit) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
An ID of the page in the paginated results.
1104 1105 1106 1107 1108 1109 1110 1111 1112 1113 1114 1115 1116 1117 1118 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 1104 class DescribeBatchPredictionsInput < Struct.new( :filter_variable, :eq, :gt, :lt, :ge, :le, :ne, :prefix, :sort_order, :next_token, :limit) SENSITIVE = [] include Aws::Structure end |
#prefix ⇒ String
A string that is found at the beginning of a variable, such as Name or Id.
For example, a ‘Batch Prediction` operation could have the Name 2014-09-09-HolidayGiftMailer. To search for this BatchPrediction, select Name for the FilterVariable and any of the following strings for the Prefix:
-
2014-09
-
2014-09-09
-
2014-09-09-Holiday
1104 1105 1106 1107 1108 1109 1110 1111 1112 1113 1114 1115 1116 1117 1118 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 1104 class DescribeBatchPredictionsInput < Struct.new( :filter_variable, :eq, :gt, :lt, :ge, :le, :ne, :prefix, :sort_order, :next_token, :limit) SENSITIVE = [] include Aws::Structure end |
#sort_order ⇒ String
A two-value parameter that determines the sequence of the resulting list of ‘MLModel`s.
-
asc- Arranges the list in ascending order (A-Z, 0-9). -
dsc- Arranges the list in descending order (Z-A, 9-0).
Results are sorted by FilterVariable.
1104 1105 1106 1107 1108 1109 1110 1111 1112 1113 1114 1115 1116 1117 1118 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 1104 class DescribeBatchPredictionsInput < Struct.new( :filter_variable, :eq, :gt, :lt, :ge, :le, :ne, :prefix, :sort_order, :next_token, :limit) SENSITIVE = [] include Aws::Structure end |