Class: Aws::MachineLearning::Types::DescribeDataSourcesInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::MachineLearning::Types::DescribeDataSourcesInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-machinelearning/types.rb
Overview
When making an API call, you may pass DescribeDataSourcesInput data as a hash:
{
filter_variable: "CreatedAt", # accepts CreatedAt, LastUpdatedAt, Status, Name, DataLocationS3, IAMUser
eq: "ComparatorValue",
gt: "ComparatorValue",
lt: "ComparatorValue",
ge: "ComparatorValue",
le: "ComparatorValue",
ne: "ComparatorValue",
prefix: "ComparatorValue",
sort_order: "asc", # accepts asc, dsc
next_token: "StringType",
limit: 1,
}
Instance Attribute Summary collapse
-
#eq ⇒ String
The equal to operator.
-
#filter_variable ⇒ String
Use one of the following variables to filter a list of
DataSource:. -
#ge ⇒ String
The greater than or equal to operator.
-
#gt ⇒ String
The greater than operator.
-
#le ⇒ String
The less than or equal to operator.
-
#limit ⇒ Integer
The maximum number of
DataSourceto include in the result. -
#lt ⇒ String
The less than operator.
-
#ne ⇒ String
The not equal to operator.
-
#next_token ⇒ String
The ID of the page in the paginated results.
-
#prefix ⇒ String
A string that is found at the beginning of a variable, such as
NameorId. -
#sort_order ⇒ String
A two-value parameter that determines the sequence of the resulting list of
DataSource.
Instance Attribute Details
#eq ⇒ String
The equal to operator. The DataSource results will have FilterVariable values that exactly match the value specified with EQ.
1375 1376 1377 1378 1379 1380 1381 1382 1383 1384 1385 1386 1387 1388 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 1375 class DescribeDataSourcesInput < Struct.new( :filter_variable, :eq, :gt, :lt, :ge, :le, :ne, :prefix, :sort_order, :next_token, :limit) include Aws::Structure end |
#filter_variable ⇒ String
Use one of the following variables to filter a list of DataSource:
-
CreatedAt- Sets the search criteria toDataSourcecreation dates. -
Status- Sets the search criteria toDataSourcestatuses. -
Name- Sets the search criteria to the contents ofDataSourceName. -
DataUri- Sets the search criteria to the URI of data files used to create theDataSource. The URI can identify either a file or an Amazon Simple Storage Service (Amazon S3) bucket or directory. -
IAMUser- Sets the search criteria to the user account that invoked theDataSourcecreation.
1375 1376 1377 1378 1379 1380 1381 1382 1383 1384 1385 1386 1387 1388 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 1375 class DescribeDataSourcesInput < Struct.new( :filter_variable, :eq, :gt, :lt, :ge, :le, :ne, :prefix, :sort_order, :next_token, :limit) include Aws::Structure end |
#ge ⇒ String
The greater than or equal to operator. The DataSource results will have FilterVariable values that are greater than or equal to the value specified with GE.
1375 1376 1377 1378 1379 1380 1381 1382 1383 1384 1385 1386 1387 1388 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 1375 class DescribeDataSourcesInput < Struct.new( :filter_variable, :eq, :gt, :lt, :ge, :le, :ne, :prefix, :sort_order, :next_token, :limit) include Aws::Structure end |
#gt ⇒ String
The greater than operator. The DataSource results will have FilterVariable values that are greater than the value specified with GT.
1375 1376 1377 1378 1379 1380 1381 1382 1383 1384 1385 1386 1387 1388 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 1375 class DescribeDataSourcesInput < Struct.new( :filter_variable, :eq, :gt, :lt, :ge, :le, :ne, :prefix, :sort_order, :next_token, :limit) include Aws::Structure end |
#le ⇒ String
The less than or equal to operator. The DataSource results will have FilterVariable values that are less than or equal to the value specified with LE.
1375 1376 1377 1378 1379 1380 1381 1382 1383 1384 1385 1386 1387 1388 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 1375 class DescribeDataSourcesInput < Struct.new( :filter_variable, :eq, :gt, :lt, :ge, :le, :ne, :prefix, :sort_order, :next_token, :limit) include Aws::Structure end |
#limit ⇒ Integer
The maximum number of DataSource to include in the result.
1375 1376 1377 1378 1379 1380 1381 1382 1383 1384 1385 1386 1387 1388 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 1375 class DescribeDataSourcesInput < Struct.new( :filter_variable, :eq, :gt, :lt, :ge, :le, :ne, :prefix, :sort_order, :next_token, :limit) include Aws::Structure end |
#lt ⇒ String
The less than operator. The DataSource results will have FilterVariable values that are less than the value specified with LT.
1375 1376 1377 1378 1379 1380 1381 1382 1383 1384 1385 1386 1387 1388 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 1375 class DescribeDataSourcesInput < Struct.new( :filter_variable, :eq, :gt, :lt, :ge, :le, :ne, :prefix, :sort_order, :next_token, :limit) include Aws::Structure end |
#ne ⇒ String
The not equal to operator. The DataSource results will have FilterVariable values not equal to the value specified with NE.
1375 1376 1377 1378 1379 1380 1381 1382 1383 1384 1385 1386 1387 1388 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 1375 class DescribeDataSourcesInput < Struct.new( :filter_variable, :eq, :gt, :lt, :ge, :le, :ne, :prefix, :sort_order, :next_token, :limit) include Aws::Structure end |
#next_token ⇒ String
The ID of the page in the paginated results.
1375 1376 1377 1378 1379 1380 1381 1382 1383 1384 1385 1386 1387 1388 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 1375 class DescribeDataSourcesInput < Struct.new( :filter_variable, :eq, :gt, :lt, :ge, :le, :ne, :prefix, :sort_order, :next_token, :limit) include Aws::Structure end |
#prefix ⇒ String
A string that is found at the beginning of a variable, such as Name or Id.
For example, a DataSource could have the Name 2014-09-09-HolidayGiftMailer. To search for this DataSource, select Name for the FilterVariable and any of the following strings for the Prefix:
-
2014-09
-
2014-09-09
-
2014-09-09-Holiday
1375 1376 1377 1378 1379 1380 1381 1382 1383 1384 1385 1386 1387 1388 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 1375 class DescribeDataSourcesInput < Struct.new( :filter_variable, :eq, :gt, :lt, :ge, :le, :ne, :prefix, :sort_order, :next_token, :limit) include Aws::Structure end |
#sort_order ⇒ String
A two-value parameter that determines the sequence of the resulting list of DataSource.
-
asc- Arranges the list in ascending order (A-Z, 0-9). -
dsc- Arranges the list in descending order (Z-A, 9-0).
Results are sorted by FilterVariable.
1375 1376 1377 1378 1379 1380 1381 1382 1383 1384 1385 1386 1387 1388 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 1375 class DescribeDataSourcesInput < Struct.new( :filter_variable, :eq, :gt, :lt, :ge, :le, :ne, :prefix, :sort_order, :next_token, :limit) include Aws::Structure end |