Class: Aws::MachineLearning::Types::GetBatchPredictionOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::MachineLearning::Types::GetBatchPredictionOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-machinelearning/types.rb
Overview
Represents the output of a GetBatchPrediction operation and describes a BatchPrediction.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#batch_prediction_data_source_id ⇒ String
The ID of the
DataSourcethat was used to create theBatchPrediction. -
#batch_prediction_id ⇒ String
An ID assigned to the
BatchPredictionat creation. -
#compute_time ⇒ Integer
The approximate CPU time in milliseconds that Amazon Machine Learning spent processing the
BatchPrediction, normalized and scaled on computation resources. -
#created_at ⇒ Time
The time when the
BatchPredictionwas created. -
#created_by_iam_user ⇒ String
The AWS user account that invoked the
BatchPrediction. -
#finished_at ⇒ Time
The epoch time when Amazon Machine Learning marked the
BatchPredictionasCOMPLETEDorFAILED. -
#input_data_location_s3 ⇒ String
The location of the data file or directory in Amazon Simple Storage Service (Amazon S3).
-
#invalid_record_count ⇒ Integer
The number of invalid records that Amazon Machine Learning saw while processing the
BatchPrediction. -
#last_updated_at ⇒ Time
The time of the most recent edit to
BatchPrediction. -
#log_uri ⇒ String
A link to the file that contains logs of the
CreateBatchPredictionoperation. -
#message ⇒ String
A description of the most recent details about processing the batch prediction request.
-
#ml_model_id ⇒ String
The ID of the
MLModelthat generated predictions for theBatchPredictionrequest. -
#name ⇒ String
A user-supplied name or description of the
BatchPrediction. -
#output_uri ⇒ String
The location of an Amazon S3 bucket or directory to receive the operation results.
-
#started_at ⇒ Time
The epoch time when Amazon Machine Learning marked the
BatchPredictionasINPROGRESS. -
#status ⇒ String
The status of the
BatchPrediction, which can be one of the following values:. -
#total_record_count ⇒ Integer
The number of total records that Amazon Machine Learning saw while processing the
BatchPrediction.
Instance Attribute Details
#batch_prediction_data_source_id ⇒ String
The ID of the DataSource that was used to create the BatchPrediction.
1806 1807 1808 1809 1810 1811 1812 1813 1814 1815 1816 1817 1818 1819 1820 1821 1822 1823 1824 1825 1826 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 1806 class GetBatchPredictionOutput < Struct.new( :batch_prediction_id, :ml_model_id, :batch_prediction_data_source_id, :input_data_location_s3, :created_by_iam_user, :created_at, :last_updated_at, :name, :status, :output_uri, :log_uri, :message, :compute_time, :finished_at, :started_at, :total_record_count, :invalid_record_count) SENSITIVE = [] include Aws::Structure end |
#batch_prediction_id ⇒ String
An ID assigned to the BatchPrediction at creation. This value should be identical to the value of the BatchPredictionID in the request.
1806 1807 1808 1809 1810 1811 1812 1813 1814 1815 1816 1817 1818 1819 1820 1821 1822 1823 1824 1825 1826 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 1806 class GetBatchPredictionOutput < Struct.new( :batch_prediction_id, :ml_model_id, :batch_prediction_data_source_id, :input_data_location_s3, :created_by_iam_user, :created_at, :last_updated_at, :name, :status, :output_uri, :log_uri, :message, :compute_time, :finished_at, :started_at, :total_record_count, :invalid_record_count) SENSITIVE = [] include Aws::Structure end |
#compute_time ⇒ Integer
The approximate CPU time in milliseconds that Amazon Machine Learning spent processing the BatchPrediction, normalized and scaled on computation resources. ComputeTime is only available if the BatchPrediction is in the COMPLETED state.
1806 1807 1808 1809 1810 1811 1812 1813 1814 1815 1816 1817 1818 1819 1820 1821 1822 1823 1824 1825 1826 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 1806 class GetBatchPredictionOutput < Struct.new( :batch_prediction_id, :ml_model_id, :batch_prediction_data_source_id, :input_data_location_s3, :created_by_iam_user, :created_at, :last_updated_at, :name, :status, :output_uri, :log_uri, :message, :compute_time, :finished_at, :started_at, :total_record_count, :invalid_record_count) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The time when the BatchPrediction was created. The time is expressed in epoch time.
1806 1807 1808 1809 1810 1811 1812 1813 1814 1815 1816 1817 1818 1819 1820 1821 1822 1823 1824 1825 1826 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 1806 class GetBatchPredictionOutput < Struct.new( :batch_prediction_id, :ml_model_id, :batch_prediction_data_source_id, :input_data_location_s3, :created_by_iam_user, :created_at, :last_updated_at, :name, :status, :output_uri, :log_uri, :message, :compute_time, :finished_at, :started_at, :total_record_count, :invalid_record_count) SENSITIVE = [] include Aws::Structure end |
#created_by_iam_user ⇒ String
The AWS user account that invoked the BatchPrediction. The account type can be either an AWS root account or an AWS Identity and Access Management (IAM) user account.
1806 1807 1808 1809 1810 1811 1812 1813 1814 1815 1816 1817 1818 1819 1820 1821 1822 1823 1824 1825 1826 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 1806 class GetBatchPredictionOutput < Struct.new( :batch_prediction_id, :ml_model_id, :batch_prediction_data_source_id, :input_data_location_s3, :created_by_iam_user, :created_at, :last_updated_at, :name, :status, :output_uri, :log_uri, :message, :compute_time, :finished_at, :started_at, :total_record_count, :invalid_record_count) SENSITIVE = [] include Aws::Structure end |
#finished_at ⇒ Time
The epoch time when Amazon Machine Learning marked the BatchPrediction as COMPLETED or FAILED. FinishedAt is only available when the BatchPrediction is in the COMPLETED or FAILED state.
1806 1807 1808 1809 1810 1811 1812 1813 1814 1815 1816 1817 1818 1819 1820 1821 1822 1823 1824 1825 1826 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 1806 class GetBatchPredictionOutput < Struct.new( :batch_prediction_id, :ml_model_id, :batch_prediction_data_source_id, :input_data_location_s3, :created_by_iam_user, :created_at, :last_updated_at, :name, :status, :output_uri, :log_uri, :message, :compute_time, :finished_at, :started_at, :total_record_count, :invalid_record_count) SENSITIVE = [] include Aws::Structure end |
#input_data_location_s3 ⇒ String
The location of the data file or directory in Amazon Simple Storage Service (Amazon S3).
1806 1807 1808 1809 1810 1811 1812 1813 1814 1815 1816 1817 1818 1819 1820 1821 1822 1823 1824 1825 1826 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 1806 class GetBatchPredictionOutput < Struct.new( :batch_prediction_id, :ml_model_id, :batch_prediction_data_source_id, :input_data_location_s3, :created_by_iam_user, :created_at, :last_updated_at, :name, :status, :output_uri, :log_uri, :message, :compute_time, :finished_at, :started_at, :total_record_count, :invalid_record_count) SENSITIVE = [] include Aws::Structure end |
#invalid_record_count ⇒ Integer
The number of invalid records that Amazon Machine Learning saw while processing the BatchPrediction.
1806 1807 1808 1809 1810 1811 1812 1813 1814 1815 1816 1817 1818 1819 1820 1821 1822 1823 1824 1825 1826 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 1806 class GetBatchPredictionOutput < Struct.new( :batch_prediction_id, :ml_model_id, :batch_prediction_data_source_id, :input_data_location_s3, :created_by_iam_user, :created_at, :last_updated_at, :name, :status, :output_uri, :log_uri, :message, :compute_time, :finished_at, :started_at, :total_record_count, :invalid_record_count) SENSITIVE = [] include Aws::Structure end |
#last_updated_at ⇒ Time
The time of the most recent edit to BatchPrediction. The time is expressed in epoch time.
1806 1807 1808 1809 1810 1811 1812 1813 1814 1815 1816 1817 1818 1819 1820 1821 1822 1823 1824 1825 1826 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 1806 class GetBatchPredictionOutput < Struct.new( :batch_prediction_id, :ml_model_id, :batch_prediction_data_source_id, :input_data_location_s3, :created_by_iam_user, :created_at, :last_updated_at, :name, :status, :output_uri, :log_uri, :message, :compute_time, :finished_at, :started_at, :total_record_count, :invalid_record_count) SENSITIVE = [] include Aws::Structure end |
#log_uri ⇒ String
A link to the file that contains logs of the CreateBatchPrediction operation.
1806 1807 1808 1809 1810 1811 1812 1813 1814 1815 1816 1817 1818 1819 1820 1821 1822 1823 1824 1825 1826 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 1806 class GetBatchPredictionOutput < Struct.new( :batch_prediction_id, :ml_model_id, :batch_prediction_data_source_id, :input_data_location_s3, :created_by_iam_user, :created_at, :last_updated_at, :name, :status, :output_uri, :log_uri, :message, :compute_time, :finished_at, :started_at, :total_record_count, :invalid_record_count) SENSITIVE = [] include Aws::Structure end |
#message ⇒ String
A description of the most recent details about processing the batch prediction request.
1806 1807 1808 1809 1810 1811 1812 1813 1814 1815 1816 1817 1818 1819 1820 1821 1822 1823 1824 1825 1826 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 1806 class GetBatchPredictionOutput < Struct.new( :batch_prediction_id, :ml_model_id, :batch_prediction_data_source_id, :input_data_location_s3, :created_by_iam_user, :created_at, :last_updated_at, :name, :status, :output_uri, :log_uri, :message, :compute_time, :finished_at, :started_at, :total_record_count, :invalid_record_count) SENSITIVE = [] include Aws::Structure end |
#ml_model_id ⇒ String
The ID of the MLModel that generated predictions for the BatchPrediction request.
1806 1807 1808 1809 1810 1811 1812 1813 1814 1815 1816 1817 1818 1819 1820 1821 1822 1823 1824 1825 1826 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 1806 class GetBatchPredictionOutput < Struct.new( :batch_prediction_id, :ml_model_id, :batch_prediction_data_source_id, :input_data_location_s3, :created_by_iam_user, :created_at, :last_updated_at, :name, :status, :output_uri, :log_uri, :message, :compute_time, :finished_at, :started_at, :total_record_count, :invalid_record_count) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
A user-supplied name or description of the BatchPrediction.
1806 1807 1808 1809 1810 1811 1812 1813 1814 1815 1816 1817 1818 1819 1820 1821 1822 1823 1824 1825 1826 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 1806 class GetBatchPredictionOutput < Struct.new( :batch_prediction_id, :ml_model_id, :batch_prediction_data_source_id, :input_data_location_s3, :created_by_iam_user, :created_at, :last_updated_at, :name, :status, :output_uri, :log_uri, :message, :compute_time, :finished_at, :started_at, :total_record_count, :invalid_record_count) SENSITIVE = [] include Aws::Structure end |
#output_uri ⇒ String
The location of an Amazon S3 bucket or directory to receive the operation results.
1806 1807 1808 1809 1810 1811 1812 1813 1814 1815 1816 1817 1818 1819 1820 1821 1822 1823 1824 1825 1826 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 1806 class GetBatchPredictionOutput < Struct.new( :batch_prediction_id, :ml_model_id, :batch_prediction_data_source_id, :input_data_location_s3, :created_by_iam_user, :created_at, :last_updated_at, :name, :status, :output_uri, :log_uri, :message, :compute_time, :finished_at, :started_at, :total_record_count, :invalid_record_count) SENSITIVE = [] include Aws::Structure end |
#started_at ⇒ Time
The epoch time when Amazon Machine Learning marked the BatchPrediction as INPROGRESS. StartedAt isn’t available if the BatchPrediction is in the PENDING state.
1806 1807 1808 1809 1810 1811 1812 1813 1814 1815 1816 1817 1818 1819 1820 1821 1822 1823 1824 1825 1826 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 1806 class GetBatchPredictionOutput < Struct.new( :batch_prediction_id, :ml_model_id, :batch_prediction_data_source_id, :input_data_location_s3, :created_by_iam_user, :created_at, :last_updated_at, :name, :status, :output_uri, :log_uri, :message, :compute_time, :finished_at, :started_at, :total_record_count, :invalid_record_count) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the BatchPrediction, which can be one of the following values:
-
PENDING- Amazon Machine Learning (Amazon ML) submitted a request to generate batch predictions. -
INPROGRESS- The batch predictions are in progress. -
FAILED- The request to perform a batch prediction did not run to completion. It is not usable. -
COMPLETED- The batch prediction process completed successfully. -
DELETED- TheBatchPredictionis marked as deleted. It is not usable.
1806 1807 1808 1809 1810 1811 1812 1813 1814 1815 1816 1817 1818 1819 1820 1821 1822 1823 1824 1825 1826 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 1806 class GetBatchPredictionOutput < Struct.new( :batch_prediction_id, :ml_model_id, :batch_prediction_data_source_id, :input_data_location_s3, :created_by_iam_user, :created_at, :last_updated_at, :name, :status, :output_uri, :log_uri, :message, :compute_time, :finished_at, :started_at, :total_record_count, :invalid_record_count) SENSITIVE = [] include Aws::Structure end |
#total_record_count ⇒ Integer
The number of total records that Amazon Machine Learning saw while processing the BatchPrediction.
1806 1807 1808 1809 1810 1811 1812 1813 1814 1815 1816 1817 1818 1819 1820 1821 1822 1823 1824 1825 1826 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 1806 class GetBatchPredictionOutput < Struct.new( :batch_prediction_id, :ml_model_id, :batch_prediction_data_source_id, :input_data_location_s3, :created_by_iam_user, :created_at, :last_updated_at, :name, :status, :output_uri, :log_uri, :message, :compute_time, :finished_at, :started_at, :total_record_count, :invalid_record_count) SENSITIVE = [] include Aws::Structure end |