Class: Aws::MachineLearning::Types::GetDataSourceOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::MachineLearning::Types::GetDataSourceOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-machinelearning/types.rb
Overview
Represents the output of a GetDataSource operation and describes a DataSource.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#compute_statistics ⇒ Boolean
The parameter is
trueif statistics need to be generated from the observation data. -
#compute_time ⇒ Integer
The approximate CPU time in milliseconds that Amazon Machine Learning spent processing the
DataSource, normalized and scaled on computation resources. -
#created_at ⇒ Time
The time that the
DataSourcewas created. -
#created_by_iam_user ⇒ String
The AWS user account from which the
DataSourcewas created. -
#data_location_s3 ⇒ String
The location of the data file or directory in Amazon Simple Storage Service (Amazon S3).
-
#data_rearrangement ⇒ String
A JSON string that represents the splitting and rearrangement requirement used when this
DataSourcewas created. -
#data_size_in_bytes ⇒ Integer
The total size of observations in the data files.
-
#data_source_id ⇒ String
The ID assigned to the
DataSourceat creation. -
#data_source_schema ⇒ String
The schema used by all of the data files of this
DataSource. -
#finished_at ⇒ Time
The epoch time when Amazon Machine Learning marked the
DataSourceasCOMPLETEDorFAILED. -
#last_updated_at ⇒ Time
The time of the most recent edit to the
DataSource. -
#log_uri ⇒ String
A link to the file containing logs of
CreateDataSourceFrom*operations. -
#message ⇒ String
The user-supplied description of the most recent details about creating the
DataSource. -
#name ⇒ String
A user-supplied name or description of the
DataSource. -
#number_of_files ⇒ Integer
The number of data files referenced by the
DataSource. -
#rds_metadata ⇒ Types::RDSMetadata
The datasource details that are specific to Amazon RDS.
-
#redshift_metadata ⇒ Types::RedshiftMetadata
Describes the
DataSourcedetails specific to Amazon Redshift. -
#role_arn ⇒ String
The Amazon Resource Name (ARN) of an [AWS IAM Role], such as the following: arn:aws:iam::account:role/rolename.
-
#started_at ⇒ Time
The epoch time when Amazon Machine Learning marked the
DataSourceasINPROGRESS. -
#status ⇒ String
The current status of the
DataSource.
Instance Attribute Details
#compute_statistics ⇒ Boolean
The parameter is true if statistics need to be generated from the observation data.
1970 1971 1972 1973 1974 1975 1976 1977 1978 1979 1980 1981 1982 1983 1984 1985 1986 1987 1988 1989 1990 1991 1992 1993 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 1970 class GetDataSourceOutput < Struct.new( :data_source_id, :data_location_s3, :data_rearrangement, :created_by_iam_user, :created_at, :last_updated_at, :data_size_in_bytes, :number_of_files, :name, :status, :log_uri, :message, :redshift_metadata, :rds_metadata, :role_arn, :compute_statistics, :compute_time, :finished_at, :started_at, :data_source_schema) SENSITIVE = [] include Aws::Structure end |
#compute_time ⇒ Integer
The approximate CPU time in milliseconds that Amazon Machine Learning spent processing the DataSource, normalized and scaled on computation resources. ComputeTime is only available if the DataSource is in the COMPLETED state and the ComputeStatistics is set to true.
1970 1971 1972 1973 1974 1975 1976 1977 1978 1979 1980 1981 1982 1983 1984 1985 1986 1987 1988 1989 1990 1991 1992 1993 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 1970 class GetDataSourceOutput < Struct.new( :data_source_id, :data_location_s3, :data_rearrangement, :created_by_iam_user, :created_at, :last_updated_at, :data_size_in_bytes, :number_of_files, :name, :status, :log_uri, :message, :redshift_metadata, :rds_metadata, :role_arn, :compute_statistics, :compute_time, :finished_at, :started_at, :data_source_schema) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The time that the DataSource was created. The time is expressed in epoch time.
1970 1971 1972 1973 1974 1975 1976 1977 1978 1979 1980 1981 1982 1983 1984 1985 1986 1987 1988 1989 1990 1991 1992 1993 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 1970 class GetDataSourceOutput < Struct.new( :data_source_id, :data_location_s3, :data_rearrangement, :created_by_iam_user, :created_at, :last_updated_at, :data_size_in_bytes, :number_of_files, :name, :status, :log_uri, :message, :redshift_metadata, :rds_metadata, :role_arn, :compute_statistics, :compute_time, :finished_at, :started_at, :data_source_schema) SENSITIVE = [] include Aws::Structure end |
#created_by_iam_user ⇒ String
The AWS user account from which the DataSource was created. The account type can be either an AWS root account or an AWS Identity and Access Management (IAM) user account.
1970 1971 1972 1973 1974 1975 1976 1977 1978 1979 1980 1981 1982 1983 1984 1985 1986 1987 1988 1989 1990 1991 1992 1993 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 1970 class GetDataSourceOutput < Struct.new( :data_source_id, :data_location_s3, :data_rearrangement, :created_by_iam_user, :created_at, :last_updated_at, :data_size_in_bytes, :number_of_files, :name, :status, :log_uri, :message, :redshift_metadata, :rds_metadata, :role_arn, :compute_statistics, :compute_time, :finished_at, :started_at, :data_source_schema) SENSITIVE = [] include Aws::Structure end |
#data_location_s3 ⇒ String
The location of the data file or directory in Amazon Simple Storage Service (Amazon S3).
1970 1971 1972 1973 1974 1975 1976 1977 1978 1979 1980 1981 1982 1983 1984 1985 1986 1987 1988 1989 1990 1991 1992 1993 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 1970 class GetDataSourceOutput < Struct.new( :data_source_id, :data_location_s3, :data_rearrangement, :created_by_iam_user, :created_at, :last_updated_at, :data_size_in_bytes, :number_of_files, :name, :status, :log_uri, :message, :redshift_metadata, :rds_metadata, :role_arn, :compute_statistics, :compute_time, :finished_at, :started_at, :data_source_schema) SENSITIVE = [] include Aws::Structure end |
#data_rearrangement ⇒ String
A JSON string that represents the splitting and rearrangement requirement used when this DataSource was created.
1970 1971 1972 1973 1974 1975 1976 1977 1978 1979 1980 1981 1982 1983 1984 1985 1986 1987 1988 1989 1990 1991 1992 1993 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 1970 class GetDataSourceOutput < Struct.new( :data_source_id, :data_location_s3, :data_rearrangement, :created_by_iam_user, :created_at, :last_updated_at, :data_size_in_bytes, :number_of_files, :name, :status, :log_uri, :message, :redshift_metadata, :rds_metadata, :role_arn, :compute_statistics, :compute_time, :finished_at, :started_at, :data_source_schema) SENSITIVE = [] include Aws::Structure end |
#data_size_in_bytes ⇒ Integer
The total size of observations in the data files.
1970 1971 1972 1973 1974 1975 1976 1977 1978 1979 1980 1981 1982 1983 1984 1985 1986 1987 1988 1989 1990 1991 1992 1993 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 1970 class GetDataSourceOutput < Struct.new( :data_source_id, :data_location_s3, :data_rearrangement, :created_by_iam_user, :created_at, :last_updated_at, :data_size_in_bytes, :number_of_files, :name, :status, :log_uri, :message, :redshift_metadata, :rds_metadata, :role_arn, :compute_statistics, :compute_time, :finished_at, :started_at, :data_source_schema) SENSITIVE = [] include Aws::Structure end |
#data_source_id ⇒ String
The ID assigned to the DataSource at creation. This value should be identical to the value of the DataSourceId in the request.
1970 1971 1972 1973 1974 1975 1976 1977 1978 1979 1980 1981 1982 1983 1984 1985 1986 1987 1988 1989 1990 1991 1992 1993 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 1970 class GetDataSourceOutput < Struct.new( :data_source_id, :data_location_s3, :data_rearrangement, :created_by_iam_user, :created_at, :last_updated_at, :data_size_in_bytes, :number_of_files, :name, :status, :log_uri, :message, :redshift_metadata, :rds_metadata, :role_arn, :compute_statistics, :compute_time, :finished_at, :started_at, :data_source_schema) SENSITIVE = [] include Aws::Structure end |
#data_source_schema ⇒ String
The schema used by all of the data files of this DataSource.
Note: This parameter is provided as part of the verbose format.
1970 1971 1972 1973 1974 1975 1976 1977 1978 1979 1980 1981 1982 1983 1984 1985 1986 1987 1988 1989 1990 1991 1992 1993 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 1970 class GetDataSourceOutput < Struct.new( :data_source_id, :data_location_s3, :data_rearrangement, :created_by_iam_user, :created_at, :last_updated_at, :data_size_in_bytes, :number_of_files, :name, :status, :log_uri, :message, :redshift_metadata, :rds_metadata, :role_arn, :compute_statistics, :compute_time, :finished_at, :started_at, :data_source_schema) SENSITIVE = [] include Aws::Structure end |
#finished_at ⇒ Time
The epoch time when Amazon Machine Learning marked the DataSource as COMPLETED or FAILED. FinishedAt is only available when the DataSource is in the COMPLETED or FAILED state.
1970 1971 1972 1973 1974 1975 1976 1977 1978 1979 1980 1981 1982 1983 1984 1985 1986 1987 1988 1989 1990 1991 1992 1993 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 1970 class GetDataSourceOutput < Struct.new( :data_source_id, :data_location_s3, :data_rearrangement, :created_by_iam_user, :created_at, :last_updated_at, :data_size_in_bytes, :number_of_files, :name, :status, :log_uri, :message, :redshift_metadata, :rds_metadata, :role_arn, :compute_statistics, :compute_time, :finished_at, :started_at, :data_source_schema) SENSITIVE = [] include Aws::Structure end |
#last_updated_at ⇒ Time
The time of the most recent edit to the DataSource. The time is expressed in epoch time.
1970 1971 1972 1973 1974 1975 1976 1977 1978 1979 1980 1981 1982 1983 1984 1985 1986 1987 1988 1989 1990 1991 1992 1993 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 1970 class GetDataSourceOutput < Struct.new( :data_source_id, :data_location_s3, :data_rearrangement, :created_by_iam_user, :created_at, :last_updated_at, :data_size_in_bytes, :number_of_files, :name, :status, :log_uri, :message, :redshift_metadata, :rds_metadata, :role_arn, :compute_statistics, :compute_time, :finished_at, :started_at, :data_source_schema) SENSITIVE = [] include Aws::Structure end |
#log_uri ⇒ String
A link to the file containing logs of CreateDataSourceFrom* operations.
1970 1971 1972 1973 1974 1975 1976 1977 1978 1979 1980 1981 1982 1983 1984 1985 1986 1987 1988 1989 1990 1991 1992 1993 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 1970 class GetDataSourceOutput < Struct.new( :data_source_id, :data_location_s3, :data_rearrangement, :created_by_iam_user, :created_at, :last_updated_at, :data_size_in_bytes, :number_of_files, :name, :status, :log_uri, :message, :redshift_metadata, :rds_metadata, :role_arn, :compute_statistics, :compute_time, :finished_at, :started_at, :data_source_schema) SENSITIVE = [] include Aws::Structure end |
#message ⇒ String
The user-supplied description of the most recent details about creating the DataSource.
1970 1971 1972 1973 1974 1975 1976 1977 1978 1979 1980 1981 1982 1983 1984 1985 1986 1987 1988 1989 1990 1991 1992 1993 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 1970 class GetDataSourceOutput < Struct.new( :data_source_id, :data_location_s3, :data_rearrangement, :created_by_iam_user, :created_at, :last_updated_at, :data_size_in_bytes, :number_of_files, :name, :status, :log_uri, :message, :redshift_metadata, :rds_metadata, :role_arn, :compute_statistics, :compute_time, :finished_at, :started_at, :data_source_schema) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
A user-supplied name or description of the DataSource.
1970 1971 1972 1973 1974 1975 1976 1977 1978 1979 1980 1981 1982 1983 1984 1985 1986 1987 1988 1989 1990 1991 1992 1993 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 1970 class GetDataSourceOutput < Struct.new( :data_source_id, :data_location_s3, :data_rearrangement, :created_by_iam_user, :created_at, :last_updated_at, :data_size_in_bytes, :number_of_files, :name, :status, :log_uri, :message, :redshift_metadata, :rds_metadata, :role_arn, :compute_statistics, :compute_time, :finished_at, :started_at, :data_source_schema) SENSITIVE = [] include Aws::Structure end |
#number_of_files ⇒ Integer
The number of data files referenced by the DataSource.
1970 1971 1972 1973 1974 1975 1976 1977 1978 1979 1980 1981 1982 1983 1984 1985 1986 1987 1988 1989 1990 1991 1992 1993 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 1970 class GetDataSourceOutput < Struct.new( :data_source_id, :data_location_s3, :data_rearrangement, :created_by_iam_user, :created_at, :last_updated_at, :data_size_in_bytes, :number_of_files, :name, :status, :log_uri, :message, :redshift_metadata, :rds_metadata, :role_arn, :compute_statistics, :compute_time, :finished_at, :started_at, :data_source_schema) SENSITIVE = [] include Aws::Structure end |
#rds_metadata ⇒ Types::RDSMetadata
The datasource details that are specific to Amazon RDS.
1970 1971 1972 1973 1974 1975 1976 1977 1978 1979 1980 1981 1982 1983 1984 1985 1986 1987 1988 1989 1990 1991 1992 1993 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 1970 class GetDataSourceOutput < Struct.new( :data_source_id, :data_location_s3, :data_rearrangement, :created_by_iam_user, :created_at, :last_updated_at, :data_size_in_bytes, :number_of_files, :name, :status, :log_uri, :message, :redshift_metadata, :rds_metadata, :role_arn, :compute_statistics, :compute_time, :finished_at, :started_at, :data_source_schema) SENSITIVE = [] include Aws::Structure end |
#redshift_metadata ⇒ Types::RedshiftMetadata
Describes the DataSource details specific to Amazon Redshift.
1970 1971 1972 1973 1974 1975 1976 1977 1978 1979 1980 1981 1982 1983 1984 1985 1986 1987 1988 1989 1990 1991 1992 1993 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 1970 class GetDataSourceOutput < Struct.new( :data_source_id, :data_location_s3, :data_rearrangement, :created_by_iam_user, :created_at, :last_updated_at, :data_size_in_bytes, :number_of_files, :name, :status, :log_uri, :message, :redshift_metadata, :rds_metadata, :role_arn, :compute_statistics, :compute_time, :finished_at, :started_at, :data_source_schema) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The Amazon Resource Name (ARN) of an [AWS IAM Role], such as the following: arn:aws:iam::account:role/rolename.
[1]: docs.aws.amazon.com/IAM/latest/UserGuide/roles-toplevel.html#roles-about-termsandconcepts
1970 1971 1972 1973 1974 1975 1976 1977 1978 1979 1980 1981 1982 1983 1984 1985 1986 1987 1988 1989 1990 1991 1992 1993 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 1970 class GetDataSourceOutput < Struct.new( :data_source_id, :data_location_s3, :data_rearrangement, :created_by_iam_user, :created_at, :last_updated_at, :data_size_in_bytes, :number_of_files, :name, :status, :log_uri, :message, :redshift_metadata, :rds_metadata, :role_arn, :compute_statistics, :compute_time, :finished_at, :started_at, :data_source_schema) SENSITIVE = [] include Aws::Structure end |
#started_at ⇒ Time
The epoch time when Amazon Machine Learning marked the DataSource as INPROGRESS. StartedAt isn’t available if the DataSource is in the PENDING state.
1970 1971 1972 1973 1974 1975 1976 1977 1978 1979 1980 1981 1982 1983 1984 1985 1986 1987 1988 1989 1990 1991 1992 1993 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 1970 class GetDataSourceOutput < Struct.new( :data_source_id, :data_location_s3, :data_rearrangement, :created_by_iam_user, :created_at, :last_updated_at, :data_size_in_bytes, :number_of_files, :name, :status, :log_uri, :message, :redshift_metadata, :rds_metadata, :role_arn, :compute_statistics, :compute_time, :finished_at, :started_at, :data_source_schema) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the DataSource. This element can have one of the following values:
-
PENDING- Amazon ML submitted a request to create aDataSource. -
INPROGRESS- The creation process is underway. -
FAILED- The request to create aDataSourcedid not run to completion. It is not usable. -
COMPLETED- The creation process completed successfully. -
DELETED- TheDataSourceis marked as deleted. It is not usable.
1970 1971 1972 1973 1974 1975 1976 1977 1978 1979 1980 1981 1982 1983 1984 1985 1986 1987 1988 1989 1990 1991 1992 1993 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 1970 class GetDataSourceOutput < Struct.new( :data_source_id, :data_location_s3, :data_rearrangement, :created_by_iam_user, :created_at, :last_updated_at, :data_size_in_bytes, :number_of_files, :name, :status, :log_uri, :message, :redshift_metadata, :rds_metadata, :role_arn, :compute_statistics, :compute_time, :finished_at, :started_at, :data_source_schema) SENSITIVE = [] include Aws::Structure end |