Class: Aws::MachineLearning::Types::GetEvaluationOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::MachineLearning::Types::GetEvaluationOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-machinelearning/types.rb
Overview
Represents the output of a GetEvaluation operation and describes an Evaluation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#compute_time ⇒ Integer
The approximate CPU time in milliseconds that Amazon Machine Learning spent processing the
Evaluation, normalized and scaled on computation resources. -
#created_at ⇒ Time
The time that the
Evaluationwas created. -
#created_by_iam_user ⇒ String
The AWS user account that invoked the evaluation.
-
#evaluation_data_source_id ⇒ String
The
DataSourceused for this evaluation. -
#evaluation_id ⇒ String
The evaluation ID which is same as the
EvaluationIdin the request. -
#finished_at ⇒ Time
The epoch time when Amazon Machine Learning marked the
EvaluationasCOMPLETEDorFAILED. -
#input_data_location_s3 ⇒ String
The location of the data file or directory in Amazon Simple Storage Service (Amazon S3).
-
#last_updated_at ⇒ Time
The time of the most recent edit to the
Evaluation. -
#log_uri ⇒ String
A link to the file that contains logs of the
CreateEvaluationoperation. -
#message ⇒ String
A description of the most recent details about evaluating the
MLModel. -
#ml_model_id ⇒ String
The ID of the
MLModelthat was the focus of the evaluation. -
#name ⇒ String
A user-supplied name or description of the
Evaluation. -
#performance_metrics ⇒ Types::PerformanceMetrics
Measurements of how well the
MLModelperformed using observations referenced by theDataSource. -
#started_at ⇒ Time
The epoch time when Amazon Machine Learning marked the
EvaluationasINPROGRESS. -
#status ⇒ String
The status of the evaluation.
Instance Attribute Details
#compute_time ⇒ Integer
The approximate CPU time in milliseconds that Amazon Machine Learning spent processing the Evaluation, normalized and scaled on computation resources. ComputeTime is only available if the Evaluation is in the COMPLETED state.
2119 2120 2121 2122 2123 2124 2125 2126 2127 2128 2129 2130 2131 2132 2133 2134 2135 2136 2137 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 2119 class GetEvaluationOutput < Struct.new( :evaluation_id, :ml_model_id, :evaluation_data_source_id, :input_data_location_s3, :created_by_iam_user, :created_at, :last_updated_at, :name, :status, :performance_metrics, :log_uri, :message, :compute_time, :finished_at, :started_at) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The time that the Evaluation was created. The time is expressed in epoch time.
2119 2120 2121 2122 2123 2124 2125 2126 2127 2128 2129 2130 2131 2132 2133 2134 2135 2136 2137 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 2119 class GetEvaluationOutput < Struct.new( :evaluation_id, :ml_model_id, :evaluation_data_source_id, :input_data_location_s3, :created_by_iam_user, :created_at, :last_updated_at, :name, :status, :performance_metrics, :log_uri, :message, :compute_time, :finished_at, :started_at) SENSITIVE = [] include Aws::Structure end |
#created_by_iam_user ⇒ String
The AWS user account that invoked the evaluation. The account type can be either an AWS root account or an AWS Identity and Access Management (IAM) user account.
2119 2120 2121 2122 2123 2124 2125 2126 2127 2128 2129 2130 2131 2132 2133 2134 2135 2136 2137 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 2119 class GetEvaluationOutput < Struct.new( :evaluation_id, :ml_model_id, :evaluation_data_source_id, :input_data_location_s3, :created_by_iam_user, :created_at, :last_updated_at, :name, :status, :performance_metrics, :log_uri, :message, :compute_time, :finished_at, :started_at) SENSITIVE = [] include Aws::Structure end |
#evaluation_data_source_id ⇒ String
The DataSource used for this evaluation.
2119 2120 2121 2122 2123 2124 2125 2126 2127 2128 2129 2130 2131 2132 2133 2134 2135 2136 2137 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 2119 class GetEvaluationOutput < Struct.new( :evaluation_id, :ml_model_id, :evaluation_data_source_id, :input_data_location_s3, :created_by_iam_user, :created_at, :last_updated_at, :name, :status, :performance_metrics, :log_uri, :message, :compute_time, :finished_at, :started_at) SENSITIVE = [] include Aws::Structure end |
#evaluation_id ⇒ String
The evaluation ID which is same as the EvaluationId in the request.
2119 2120 2121 2122 2123 2124 2125 2126 2127 2128 2129 2130 2131 2132 2133 2134 2135 2136 2137 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 2119 class GetEvaluationOutput < Struct.new( :evaluation_id, :ml_model_id, :evaluation_data_source_id, :input_data_location_s3, :created_by_iam_user, :created_at, :last_updated_at, :name, :status, :performance_metrics, :log_uri, :message, :compute_time, :finished_at, :started_at) SENSITIVE = [] include Aws::Structure end |
#finished_at ⇒ Time
The epoch time when Amazon Machine Learning marked the Evaluation as COMPLETED or FAILED. FinishedAt is only available when the Evaluation is in the COMPLETED or FAILED state.
2119 2120 2121 2122 2123 2124 2125 2126 2127 2128 2129 2130 2131 2132 2133 2134 2135 2136 2137 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 2119 class GetEvaluationOutput < Struct.new( :evaluation_id, :ml_model_id, :evaluation_data_source_id, :input_data_location_s3, :created_by_iam_user, :created_at, :last_updated_at, :name, :status, :performance_metrics, :log_uri, :message, :compute_time, :finished_at, :started_at) SENSITIVE = [] include Aws::Structure end |
#input_data_location_s3 ⇒ String
The location of the data file or directory in Amazon Simple Storage Service (Amazon S3).
2119 2120 2121 2122 2123 2124 2125 2126 2127 2128 2129 2130 2131 2132 2133 2134 2135 2136 2137 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 2119 class GetEvaluationOutput < Struct.new( :evaluation_id, :ml_model_id, :evaluation_data_source_id, :input_data_location_s3, :created_by_iam_user, :created_at, :last_updated_at, :name, :status, :performance_metrics, :log_uri, :message, :compute_time, :finished_at, :started_at) SENSITIVE = [] include Aws::Structure end |
#last_updated_at ⇒ Time
The time of the most recent edit to the Evaluation. The time is expressed in epoch time.
2119 2120 2121 2122 2123 2124 2125 2126 2127 2128 2129 2130 2131 2132 2133 2134 2135 2136 2137 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 2119 class GetEvaluationOutput < Struct.new( :evaluation_id, :ml_model_id, :evaluation_data_source_id, :input_data_location_s3, :created_by_iam_user, :created_at, :last_updated_at, :name, :status, :performance_metrics, :log_uri, :message, :compute_time, :finished_at, :started_at) SENSITIVE = [] include Aws::Structure end |
#log_uri ⇒ String
A link to the file that contains logs of the CreateEvaluation operation.
2119 2120 2121 2122 2123 2124 2125 2126 2127 2128 2129 2130 2131 2132 2133 2134 2135 2136 2137 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 2119 class GetEvaluationOutput < Struct.new( :evaluation_id, :ml_model_id, :evaluation_data_source_id, :input_data_location_s3, :created_by_iam_user, :created_at, :last_updated_at, :name, :status, :performance_metrics, :log_uri, :message, :compute_time, :finished_at, :started_at) SENSITIVE = [] include Aws::Structure end |
#message ⇒ String
A description of the most recent details about evaluating the MLModel.
2119 2120 2121 2122 2123 2124 2125 2126 2127 2128 2129 2130 2131 2132 2133 2134 2135 2136 2137 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 2119 class GetEvaluationOutput < Struct.new( :evaluation_id, :ml_model_id, :evaluation_data_source_id, :input_data_location_s3, :created_by_iam_user, :created_at, :last_updated_at, :name, :status, :performance_metrics, :log_uri, :message, :compute_time, :finished_at, :started_at) SENSITIVE = [] include Aws::Structure end |
#ml_model_id ⇒ String
The ID of the MLModel that was the focus of the evaluation.
2119 2120 2121 2122 2123 2124 2125 2126 2127 2128 2129 2130 2131 2132 2133 2134 2135 2136 2137 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 2119 class GetEvaluationOutput < Struct.new( :evaluation_id, :ml_model_id, :evaluation_data_source_id, :input_data_location_s3, :created_by_iam_user, :created_at, :last_updated_at, :name, :status, :performance_metrics, :log_uri, :message, :compute_time, :finished_at, :started_at) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
A user-supplied name or description of the Evaluation.
2119 2120 2121 2122 2123 2124 2125 2126 2127 2128 2129 2130 2131 2132 2133 2134 2135 2136 2137 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 2119 class GetEvaluationOutput < Struct.new( :evaluation_id, :ml_model_id, :evaluation_data_source_id, :input_data_location_s3, :created_by_iam_user, :created_at, :last_updated_at, :name, :status, :performance_metrics, :log_uri, :message, :compute_time, :finished_at, :started_at) SENSITIVE = [] include Aws::Structure end |
#performance_metrics ⇒ Types::PerformanceMetrics
Measurements of how well the MLModel performed using observations referenced by the DataSource. One of the following metric is returned based on the type of the MLModel:
-
BinaryAUC: A binary
MLModeluses the Area Under the Curve (AUC) technique to measure performance. -
RegressionRMSE: A regression
MLModeluses the Root Mean Square Error (RMSE) technique to measure performance. RMSE measures the difference between predicted and actual values for a single variable. -
MulticlassAvgFScore: A multiclass
MLModeluses the F1 score technique to measure performance.
For more information about performance metrics, please see the [Amazon Machine Learning Developer Guide].
2119 2120 2121 2122 2123 2124 2125 2126 2127 2128 2129 2130 2131 2132 2133 2134 2135 2136 2137 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 2119 class GetEvaluationOutput < Struct.new( :evaluation_id, :ml_model_id, :evaluation_data_source_id, :input_data_location_s3, :created_by_iam_user, :created_at, :last_updated_at, :name, :status, :performance_metrics, :log_uri, :message, :compute_time, :finished_at, :started_at) SENSITIVE = [] include Aws::Structure end |
#started_at ⇒ Time
The epoch time when Amazon Machine Learning marked the Evaluation as INPROGRESS. StartedAt isn’t available if the Evaluation is in the PENDING state.
2119 2120 2121 2122 2123 2124 2125 2126 2127 2128 2129 2130 2131 2132 2133 2134 2135 2136 2137 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 2119 class GetEvaluationOutput < Struct.new( :evaluation_id, :ml_model_id, :evaluation_data_source_id, :input_data_location_s3, :created_by_iam_user, :created_at, :last_updated_at, :name, :status, :performance_metrics, :log_uri, :message, :compute_time, :finished_at, :started_at) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the evaluation. This element can have one of the following values:
-
PENDING- Amazon Machine Language (Amazon ML) submitted a request to evaluate anMLModel. -
INPROGRESS- The evaluation is underway. -
FAILED- The request to evaluate anMLModeldid not run to completion. It is not usable. -
COMPLETED- The evaluation process completed successfully. -
DELETED- TheEvaluationis marked as deleted. It is not usable.
2119 2120 2121 2122 2123 2124 2125 2126 2127 2128 2129 2130 2131 2132 2133 2134 2135 2136 2137 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 2119 class GetEvaluationOutput < Struct.new( :evaluation_id, :ml_model_id, :evaluation_data_source_id, :input_data_location_s3, :created_by_iam_user, :created_at, :last_updated_at, :name, :status, :performance_metrics, :log_uri, :message, :compute_time, :finished_at, :started_at) SENSITIVE = [] include Aws::Structure end |