Class: Aws::MachineLearning::Types::PerformanceMetrics
- Inherits:
-
Struct
- Object
- Struct
- Aws::MachineLearning::Types::PerformanceMetrics
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-machinelearning/types.rb
Overview
Measurements of how well the MLModel performed on known observations. One of the following metrics is returned, based on the type of the MLModel:
-
BinaryAUC: The binary
MLModeluses the Area Under the Curve (AUC) technique to measure performance. -
RegressionRMSE: The regression
MLModeluses the Root Mean Square Error (RMSE) technique to measure performance. RMSE measures the difference between predicted and actual values for a single variable. -
MulticlassAvgFScore: The multiclass
MLModeluses the F1 score technique to measure performance.
For more information about performance metrics, please see the [Amazon Machine Learning Developer Guide].
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
Instance Attribute Details
#properties ⇒ Hash<String,String>
2644 2645 2646 2647 2648 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 2644 class PerformanceMetrics < Struct.new( :properties) SENSITIVE = [] include Aws::Structure end |