Class: Aws::MachineLearning::Types::Prediction
- Inherits:
-
Struct
- Object
- Struct
- Aws::MachineLearning::Types::Prediction
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-machinelearning/types.rb
Overview
The output from a Predict operation:
-
Details- Contains the following attributes: ‘DetailsAttributes.PREDICTIVE_MODEL_TYPE - REGRESSION | BINARY | MULTICLASS` `DetailsAttributes.ALGORITHM - SGD` -
PredictedLabel- Present for either aBINARYorMULTICLASSMLModelrequest. -
PredictedScores- Contains the raw classification score corresponding to each label. -
PredictedValue- Present for aREGRESSIONMLModelrequest.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#details ⇒ Hash<String,String>
Provides any additional details regarding the prediction.
-
#predicted_label ⇒ String
The prediction label for either a
BINARYorMULTICLASSMLModel. -
#predicted_scores ⇒ Hash<String,Float>
Provides the raw classification score corresponding to each label.
-
#predicted_value ⇒ Float
The prediction value for
REGRESSIONMLModel.
Instance Attribute Details
#details ⇒ Hash<String,String>
Provides any additional details regarding the prediction.
2722 2723 2724 2725 2726 2727 2728 2729 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 2722 class Prediction < Struct.new( :predicted_label, :predicted_value, :predicted_scores, :details) SENSITIVE = [] include Aws::Structure end |
#predicted_label ⇒ String
The prediction label for either a BINARY or MULTICLASS MLModel.
2722 2723 2724 2725 2726 2727 2728 2729 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 2722 class Prediction < Struct.new( :predicted_label, :predicted_value, :predicted_scores, :details) SENSITIVE = [] include Aws::Structure end |
#predicted_scores ⇒ Hash<String,Float>
Provides the raw classification score corresponding to each label.
2722 2723 2724 2725 2726 2727 2728 2729 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 2722 class Prediction < Struct.new( :predicted_label, :predicted_value, :predicted_scores, :details) SENSITIVE = [] include Aws::Structure end |
#predicted_value ⇒ Float
The prediction value for REGRESSION MLModel.
2722 2723 2724 2725 2726 2727 2728 2729 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 2722 class Prediction < Struct.new( :predicted_label, :predicted_value, :predicted_scores, :details) SENSITIVE = [] include Aws::Structure end |