Class: Aws::MachineLearning::Types::RDSDatabaseCredentials

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-machinelearning/types.rb

Overview

The database credentials to connect to a database on an RDS DB instance.

Constant Summary collapse

SENSITIVE =
[:password]

Instance Attribute Summary collapse

Instance Attribute Details

#passwordString

The password to be used by Amazon ML to connect to a database on an RDS DB instance. The password should have sufficient permissions to execute the RDSSelectQuery query.



2987
2988
2989
2990
2991
2992
# File 'lib/aws-sdk-machinelearning/types.rb', line 2987

class RDSDatabaseCredentials < Struct.new(
  :username,
  :password)
  SENSITIVE = [:password]
  include Aws::Structure
end

#usernameString

The username to be used by Amazon ML to connect to database on an Amazon RDS instance. The username should have sufficient permissions to execute an RDSSelectSqlQuery query.



2987
2988
2989
2990
2991
2992
# File 'lib/aws-sdk-machinelearning/types.rb', line 2987

class RDSDatabaseCredentials < Struct.new(
  :username,
  :password)
  SENSITIVE = [:password]
  include Aws::Structure
end