Class: Aws::MachineLearning::Types::RedshiftDatabaseCredentials
- Inherits:
-
Struct
- Object
- Struct
- Aws::MachineLearning::Types::RedshiftDatabaseCredentials
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-machinelearning/types.rb
Overview
When making an API call, you may pass RedshiftDatabaseCredentials data as a hash:
{
username: "RedshiftDatabaseUsername", # required
password: "RedshiftDatabasePassword", # required
}Describes the database credentials for connecting to a database on an Amazon Redshift cluster.
Instance Attribute Summary collapse
-
#password ⇒ String
A password to be used by Amazon ML to connect to a database on an Amazon Redshift cluster.
-
#username ⇒ String
A username to be used by Amazon Machine Learning (Amazon ML)to connect to a database on an Amazon Redshift cluster.
Instance Attribute Details
#password ⇒ String
A password to be used by Amazon ML to connect to a database on an
Amazon Redshift cluster. The password should have sufficient
permissions to execute a RedshiftSelectSqlQuery query. The
password should be valid for an Amazon Redshift USER.
3544 3545 3546 3547 3548 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 3544 class RedshiftDatabaseCredentials < Struct.new( :username, :password) include Aws::Structure end |
#username ⇒ String
A username to be used by Amazon Machine Learning (Amazon ML)to
connect to a database on an Amazon Redshift cluster. The username
should have sufficient permissions to execute the
RedshiftSelectSqlQuery query. The username should be valid for an
Amazon Redshift USER.
3544 3545 3546 3547 3548 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 3544 class RedshiftDatabaseCredentials < Struct.new( :username, :password) include Aws::Structure end |