Class: Aws::MachineLearning::Types::RedshiftMetadata

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-machinelearning/types.rb

Overview

Describes the DataSource details specific to Amazon Redshift.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#database_user_nameString

A username to be used by Amazon Machine Learning (Amazon ML)to connect to a database on an Amazon Redshift cluster. The username should have sufficient permissions to execute the RedshiftSelectSqlQuery query. The username should be valid for an Amazon Redshift USER.



3332
3333
3334
3335
3336
3337
3338
# File 'lib/aws-sdk-machinelearning/types.rb', line 3332

class  < Struct.new(
  :redshift_database,
  :database_user_name,
  :select_sql_query)
  SENSITIVE = []
  include Aws::Structure
end

#redshift_databaseTypes::RedshiftDatabase

Describes the database details required to connect to an Amazon Redshift database.



3332
3333
3334
3335
3336
3337
3338
# File 'lib/aws-sdk-machinelearning/types.rb', line 3332

class  < Struct.new(
  :redshift_database,
  :database_user_name,
  :select_sql_query)
  SENSITIVE = []
  include Aws::Structure
end

#select_sql_queryString

The SQL query that is specified during CreateDataSourceFromRedshift. Returns only if Verbose is true in GetDataSourceInput.



3332
3333
3334
3335
3336
3337
3338
# File 'lib/aws-sdk-machinelearning/types.rb', line 3332

class  < Struct.new(
  :redshift_database,
  :database_user_name,
  :select_sql_query)
  SENSITIVE = []
  include Aws::Structure
end