Class: Aws::MachineLearning::Types::UpdateDataSourceOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::MachineLearning::Types::UpdateDataSourceOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-machinelearning/types.rb
Overview
Represents the output of an UpdateDataSource operation.
You can see the updated content by using the GetBatchPrediction operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#data_source_id ⇒ String
The ID assigned to the
DataSourceduring creation.
Instance Attribute Details
#data_source_id ⇒ String
The ID assigned to the DataSource during creation. This value should be identical to the value of the DataSourceID in the request.
3601 3602 3603 3604 3605 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 3601 class UpdateDataSourceOutput < Struct.new( :data_source_id) SENSITIVE = [] include Aws::Structure end |