Class: Aws::MachineLearning::Types::UpdateEvaluationOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::MachineLearning::Types::UpdateEvaluationOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-machinelearning/types.rb
Overview
Represents the output of an UpdateEvaluation operation.
You can see the updated content by using the GetEvaluation
operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#evaluation_id ⇒ String
The ID assigned to the
Evaluationduring creation.
Instance Attribute Details
#evaluation_id ⇒ String
The ID assigned to the Evaluation during creation. This value
should be identical to the value of the Evaluation in the request.
3636 3637 3638 3639 3640 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 3636 class UpdateEvaluationOutput < Struct.new( :evaluation_id) SENSITIVE = [] include Aws::Structure end |