Class: Aws::MachineLearning::Types::UpdateMLModelInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::MachineLearning::Types::UpdateMLModelInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-machinelearning/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#ml_model_id ⇒ String
The ID assigned to the
MLModelduring creation. -
#ml_model_name ⇒ String
A user-supplied name or description of the
MLModel. -
#score_threshold ⇒ Float
The
ScoreThresholdused in binary classificationMLModelthat marks the boundary between a positive prediction and a negative prediction.
Instance Attribute Details
#ml_model_id ⇒ String
The ID assigned to the MLModel during creation.
3658 3659 3660 3661 3662 3663 3664 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 3658 class UpdateMLModelInput < Struct.new( :ml_model_id, :ml_model_name, :score_threshold) SENSITIVE = [] include Aws::Structure end |
#ml_model_name ⇒ String
A user-supplied name or description of the MLModel.
3658 3659 3660 3661 3662 3663 3664 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 3658 class UpdateMLModelInput < Struct.new( :ml_model_id, :ml_model_name, :score_threshold) SENSITIVE = [] include Aws::Structure end |
#score_threshold ⇒ Float
The ScoreThreshold used in binary classification MLModel that marks the boundary between a positive prediction and a negative prediction.
Output values greater than or equal to the ScoreThreshold receive a positive result from the MLModel, such as true. Output values less than the ScoreThreshold receive a negative response from the MLModel, such as false.
3658 3659 3660 3661 3662 3663 3664 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 3658 class UpdateMLModelInput < Struct.new( :ml_model_id, :ml_model_name, :score_threshold) SENSITIVE = [] include Aws::Structure end |