Class: Aws::MachineLearning::Types::UpdateMLModelOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::MachineLearning::Types::UpdateMLModelOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-machinelearning/types.rb
Overview
Represents the output of an UpdateMLModel operation.
You can see the updated content by using the GetMLModel operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#ml_model_id ⇒ String
The ID assigned to the
MLModelduring creation.
Instance Attribute Details
#ml_model_id ⇒ String
The ID assigned to the MLModel during creation. This value should be identical to the value of the MLModelID in the request.
3675 3676 3677 3678 3679 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 3675 class UpdateMLModelOutput < Struct.new( :ml_model_id) SENSITIVE = [] include Aws::Structure end |