Method: Aws::MachineLearning::Types::RedshiftDatabaseCredentials#username
- Defined in:
- lib/aws-sdk-machinelearning/types.rb
#username ⇒ String
A username to be used by Amazon Machine Learning (Amazon ML)to connect to a database on an Amazon Redshift cluster. The username should have sufficient permissions to execute the RedshiftSelectSqlQuery query. The username should be valid for an Amazon Redshift [USER].
[1]: docs.aws.amazon.com/redshift/latest/dg/r_CREATE_USER.html
3303 3304 3305 3306 3307 3308 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 3303 class RedshiftDatabaseCredentials < Struct.new( :username, :password) SENSITIVE = [:password] include Aws::Structure end |