Class: Aws::MachineLearning::Types::CreateDataSourceFromRDSOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-machinelearning/types.rb

Overview

Represents the output of a CreateDataSourceFromRDS operation, and is an acknowledgement that Amazon ML received the request.

The CreateDataSourceFromRDS> operation is asynchronous. You can poll for updates by using the GetBatchPrediction operation and checking the Status parameter. You can inspect the Message when Status shows up as FAILED. You can also check the progress of the copy operation by going to the DataPipeline console and looking up the pipeline using the ‘pipelineId ` from the describe call.

Instance Attribute Summary collapse

Instance Attribute Details

#data_source_idString

A user-supplied ID that uniquely identifies the datasource. This value should be identical to the value of the DataSourceID in the request.

Returns:

  • (String)


375
376
377
378
# File 'lib/aws-sdk-machinelearning/types.rb', line 375

class CreateDataSourceFromRDSOutput < Struct.new(
  :data_source_id)
  include Aws::Structure
end