Class: Aws::MachineLearning::Types::CreateMLModelOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::MachineLearning::Types::CreateMLModelOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-machinelearning/types.rb
Overview
Represents the output of a CreateMLModel operation, and is an acknowledgement that Amazon ML received the request.
The CreateMLModel operation is asynchronous. You can poll for status updates by using the GetMLModel operation and checking the Status parameter.
Instance Attribute Summary collapse
-
#ml_model_id ⇒ String
A user-supplied ID that uniquely identifies the
MLModel.
Instance Attribute Details
#ml_model_id ⇒ String
A user-supplied ID that uniquely identifies the MLModel. This value should be identical to the value of the MLModelId in the request.
750 751 752 753 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 750 class CreateMLModelOutput < Struct.new( :ml_model_id) include Aws::Structure end |