Class: Aws::MachineLearning::Types::DescribeEvaluationsInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::MachineLearning::Types::DescribeEvaluationsInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-machinelearning/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#eq ⇒ String
The equal to operator.
-
#filter_variable ⇒ String
Use one of the following variable to filter a list of
Evaluationobjects:. -
#ge ⇒ String
The greater than or equal to operator.
-
#gt ⇒ String
The greater than operator.
-
#le ⇒ String
The less than or equal to operator.
-
#limit ⇒ Integer
The maximum number of
Evaluationto include in the result. -
#lt ⇒ String
The less than operator.
-
#ne ⇒ String
The not equal to operator.
-
#next_token ⇒ String
The ID of the page in the paginated results.
-
#prefix ⇒ String
A string that is found at the beginning of a variable, such as
NameorId. -
#sort_order ⇒ String
A two-value parameter that determines the sequence of the resulting list of
Evaluation.
Instance Attribute Details
#eq ⇒ String
The equal to operator. The Evaluation results will have FilterVariable values that exactly match the value specified with EQ.
1359 1360 1361 1362 1363 1364 1365 1366 1367 1368 1369 1370 1371 1372 1373 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 1359 class DescribeEvaluationsInput < Struct.new( :filter_variable, :eq, :gt, :lt, :ge, :le, :ne, :prefix, :sort_order, :next_token, :limit) SENSITIVE = [] include Aws::Structure end |
#filter_variable ⇒ String
Use one of the following variable to filter a list of Evaluation objects:
-
CreatedAt- Sets the search criteria to theEvaluationcreation date. -
Status- Sets the search criteria to theEvaluationstatus. -
Name- Sets the search criteria to the contents ofEvaluationName. -
IAMUser- Sets the search criteria to the user account that invoked anEvaluation. -
MLModelId- Sets the search criteria to theMLModelthat was evaluated. -
DataSourceId- Sets the search criteria to theDataSourceused inEvaluation. -
DataUri- Sets the search criteria to the data file(s) used inEvaluation. The URL can identify either a file or an Amazon Simple Storage Solution (Amazon S3) bucket or directory.
1359 1360 1361 1362 1363 1364 1365 1366 1367 1368 1369 1370 1371 1372 1373 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 1359 class DescribeEvaluationsInput < Struct.new( :filter_variable, :eq, :gt, :lt, :ge, :le, :ne, :prefix, :sort_order, :next_token, :limit) SENSITIVE = [] include Aws::Structure end |
#ge ⇒ String
The greater than or equal to operator. The Evaluation results will have FilterVariable values that are greater than or equal to the value specified with GE.
1359 1360 1361 1362 1363 1364 1365 1366 1367 1368 1369 1370 1371 1372 1373 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 1359 class DescribeEvaluationsInput < Struct.new( :filter_variable, :eq, :gt, :lt, :ge, :le, :ne, :prefix, :sort_order, :next_token, :limit) SENSITIVE = [] include Aws::Structure end |
#gt ⇒ String
The greater than operator. The Evaluation results will have FilterVariable values that are greater than the value specified with GT.
1359 1360 1361 1362 1363 1364 1365 1366 1367 1368 1369 1370 1371 1372 1373 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 1359 class DescribeEvaluationsInput < Struct.new( :filter_variable, :eq, :gt, :lt, :ge, :le, :ne, :prefix, :sort_order, :next_token, :limit) SENSITIVE = [] include Aws::Structure end |
#le ⇒ String
The less than or equal to operator. The Evaluation results will have FilterVariable values that are less than or equal to the value specified with LE.
1359 1360 1361 1362 1363 1364 1365 1366 1367 1368 1369 1370 1371 1372 1373 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 1359 class DescribeEvaluationsInput < Struct.new( :filter_variable, :eq, :gt, :lt, :ge, :le, :ne, :prefix, :sort_order, :next_token, :limit) SENSITIVE = [] include Aws::Structure end |
#limit ⇒ Integer
The maximum number of Evaluation to include in the result.
1359 1360 1361 1362 1363 1364 1365 1366 1367 1368 1369 1370 1371 1372 1373 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 1359 class DescribeEvaluationsInput < Struct.new( :filter_variable, :eq, :gt, :lt, :ge, :le, :ne, :prefix, :sort_order, :next_token, :limit) SENSITIVE = [] include Aws::Structure end |
#lt ⇒ String
The less than operator. The Evaluation results will have FilterVariable values that are less than the value specified with LT.
1359 1360 1361 1362 1363 1364 1365 1366 1367 1368 1369 1370 1371 1372 1373 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 1359 class DescribeEvaluationsInput < Struct.new( :filter_variable, :eq, :gt, :lt, :ge, :le, :ne, :prefix, :sort_order, :next_token, :limit) SENSITIVE = [] include Aws::Structure end |
#ne ⇒ String
The not equal to operator. The Evaluation results will have FilterVariable values not equal to the value specified with NE.
1359 1360 1361 1362 1363 1364 1365 1366 1367 1368 1369 1370 1371 1372 1373 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 1359 class DescribeEvaluationsInput < Struct.new( :filter_variable, :eq, :gt, :lt, :ge, :le, :ne, :prefix, :sort_order, :next_token, :limit) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The ID of the page in the paginated results.
1359 1360 1361 1362 1363 1364 1365 1366 1367 1368 1369 1370 1371 1372 1373 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 1359 class DescribeEvaluationsInput < Struct.new( :filter_variable, :eq, :gt, :lt, :ge, :le, :ne, :prefix, :sort_order, :next_token, :limit) SENSITIVE = [] include Aws::Structure end |
#prefix ⇒ String
A string that is found at the beginning of a variable, such as Name or Id.
For example, an Evaluation could have the Name 2014-09-09-HolidayGiftMailer. To search for this Evaluation, select Name for the FilterVariable and any of the following strings for the Prefix:
-
2014-09
-
2014-09-09
-
2014-09-09-Holiday
1359 1360 1361 1362 1363 1364 1365 1366 1367 1368 1369 1370 1371 1372 1373 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 1359 class DescribeEvaluationsInput < Struct.new( :filter_variable, :eq, :gt, :lt, :ge, :le, :ne, :prefix, :sort_order, :next_token, :limit) SENSITIVE = [] include Aws::Structure end |
#sort_order ⇒ String
A two-value parameter that determines the sequence of the resulting list of Evaluation.
-
asc- Arranges the list in ascending order (A-Z, 0-9). -
dsc- Arranges the list in descending order (Z-A, 9-0).
Results are sorted by FilterVariable.
1359 1360 1361 1362 1363 1364 1365 1366 1367 1368 1369 1370 1371 1372 1373 |
# File 'lib/aws-sdk-machinelearning/types.rb', line 1359 class DescribeEvaluationsInput < Struct.new( :filter_variable, :eq, :gt, :lt, :ge, :le, :ne, :prefix, :sort_order, :next_token, :limit) SENSITIVE = [] include Aws::Structure end |